#Analyses of eggspots deep & shallow
#repeated (3) samples from each fish 
#PCA

library(MASS)
library(lme4)
library(ggplot2)
library(stats)
library(effects)
library(splines)
library(xlsx)
library(car)
library(lattice)
library(grid)
library(gridExtra)
library(pbkrtest)

str(spots_rear)

spots_rear$fam <- as.factor(spots_rear$fam)
spots_rear$momID <- as.factor(spots_rear$momID)
spots_rear$dadID <- as.factor(spots_rear$dadID)
spots_rear$tag <- as.factor(spots_rear$tag)
spots_rear$tank <- as.factor(spots_rear$tank)
spots_rear$position <- as.factor(spots_rear$position)
spots_rear$rearlight <- as.factor(spots_rear$rearlight)
spots_rear$species <- as.factor(spots_rear$species)

str(spots_rear)

hist(spots_rear$spots_orange)
hist(spots_rear$spots_red)
hist(spots_rear$spots_yellow)

#PCA of three eggspot colours
egg <- prcomp(~spots_red + spots_orange + spots_yellow, data=spots_rear, scale.=TRUE)
# with standardized mean 

summary(egg)
plot(egg) 
plot(egg,type="lines")
biplot(egg, scale =0)# biplot; scale = 0 insures arrows reflect loadings
egg$rotation #Loading matrix

#to add PC's to exisiting data frame for analysis
str(egg)
spots_rear<-cbind(spots_rear,egg$x)

write.xlsx(egg$rotation, "/Users/dswright08/Desktop/egg.xlsx") 


#####do spots differ in PC1####
e1 <- lmer(PC1~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=spots_rear)
rand(e1) #only tag needed

e1a <- lmer(PC1~rearlight*species+SL+(1|tag),data=spots_rear)
AIC(e1,e1a) #without tank is better
rand(e1a)

plot(e1a)

drop1(e1a,test="Chisq")
e2 <- update(e1a,.~.-rearlight:species)
drop1(e2,test="Chisq")
e3 <- update(e2,.~.-SL)
drop1(e3,test="Chisq") 
e4 <- update(e3,.~.-rearlight)
drop1(e4,test="Chisq")
e5 <- update(e4,.~.-species)
drop1(e5,test="Chisq")

#NO differences in PC1

e5a <- update(e5,.~.+rearlight)
e5b <- update(e5,.~.+SL)

KRmodcomp(e4,e5) #species = 0.25
KRmodcomp(e5b,e5) #SL = 0.37
KRmodcomp(e5a,e5) #rearlight = 0.30



#####do spots differ in PC2####
e10 <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=spots_rear)
rand(e10) #only tag, maybe mom

e10a <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|momID),data=spots_rear)
AIC(e10,e10a) #with momID better
rand(e10a)

plot(e10a)

drop1(e10a,test="Chisq")
e12 <- update(e10a,.~.-rearlight:species)
drop1(e12,test="Chisq")
e13 <- update(e12,.~.-SL)
drop1(e13,test="Chisq") 
e14 <- update(e13,.~.-rearlight)
drop1(e14,test="Chisq") #species sig
e15 <- update(e14,.~.-species)
drop1(e15,test="Chisq")

plot(allEffects(e14))

e15a <- update(e15,.~.+rearlight)
e15b <- update(e15,.~.+SL)

KRmodcomp(e14,e15) #species = 0.15
KRmodcomp(e15b,e15) #SL = 0.85
KRmodcomp(e15a,e15) #rearlight = 0.17

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(e14, linfct=mcp(species="Tukey"))
summary(posthoc)
plot(allEffects(e14))
#Nye and Hybrid differ slightly, no others


#####Are there differences in the number of spots?#####

hist(spots_rear$number) #seems to have a negative binomial distribution

e20 <- glmer.nb(number~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=spots_rear)
e20a <- glmer.nb(number~rearlight*species+SL+(1|tag)+(1|tank)+(1|momID)+(1|dadID),data=spots_rear)
AIC(e20,e20a) #without position is better

e20b <- glmer.nb(number~rearlight*species+SL+(1|tag)+(1|momID)+(1|dadID),data=spots_rear)
AIC(e20a,e20b) #without tank is better

e20c <- glmer.nb(number~rearlight*species+SL+(1|tag)+(1|momID),data=spots_rear)
AIC(e20b,e20c) #without dadID is better

e20d <- glmer.nb(number~rearlight*species+SL+(1|tag),data=spots_rear)
AIC(e20c,e20d) #without momID is better

plot(e20d)

drop1(e20d,test="Chisq")
e22 <- update(e20d,.~.-rearlight:species)
drop1(e22,test="Chisq") 
e23 <- update(e22,.~.-rearlight)
drop1(e23,test="Chisq") 
e24 <- update(e23,.~.-SL)
drop1(e24,test="Chisq")

plot(allEffects(e24))

posthoc<-glht(e24, linfct=mcp(species="Tukey"))
summary(posthoc)

e25 <- update(e24,.~.-species)
drop1(e25,test="Chisq")

e25a <- update(e25,.~.+SL)
e25b <- update(e25,.~.+rearlight)

drop1(e24,test="Chisq") #species = 0.014
summary(e24)
drop1(e25a,test="Chisq") #SL = 0.11
drop1(e25b,test="Chisq") #rearlight = 0.37


#means per group
aggregate(spots_rear[, 14], list(spots_rear$species), mean)
aggregate(spots_rear[, 14], list(spots_rear$species), sd)

#using dataset spot_bar_graph of means and standard error

limits <- aes(ymax = mean + se, ymin=mean - se)

spot_bar_graph$species1 <- factor(spot_bar_graph$species, c("P. nyererei", "Hybrid","P. pundamilia"))

ggplot(spot_bar_graph, aes(x = species1, y = mean, fill=species1)) +
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  scale_y_continuous(expand = c(0, 0), limits = c(0, 5))+ 
  geom_bar(stat = "identity",position="dodge",width=0.7) +
  geom_errorbar(limits, position=position_dodge(width=0.9), width=0.20)+
  scale_fill_manual(values=c("red2","forestgreen","mediumblue"),labels=c("P. nyererei","Hybrid","P. pundamilia"),
  guide = F)+
  scale_x_discrete(name="", labels=c("P. nyererei","Hybrid","P. pundamilia"))+
  theme(axis.text.x = element_text(size=12,face="bold"))+
  theme(legend.position="",legend.background = element_rect(colour = 'white'),
  panel.spacing = unit(1,"lines"))+
  labs(x="",y="Anal fin spot count")



#####do spots differ in the amount coverage?#####
#calculated as total colour/total pixels 

spots_rear$tot.cov <- (spots_rear$spots_pixel/spots_rear$anal_pixel)*100
hist(spots_rear$tot.cov) #fairly normal distribution

c1 <- lmer(tot.cov~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|fam),data=spots_rear)
rand(c1) #only tag needed

c1.1 <- lmer(tot.cov~rearlight*species+SL+(1|tag),data=spots_rear)
plot(c1.1)                                                                                                    
                                                                                                    
drop1(c1.1, test="Chisq")                                                                                                    
c2 <- update(c1.1,.~.-rearlight:species)                                                                                                    
drop1(c2, test="Chisq")                                                                                                    
c3 <- update(c2,.~.-rearlight)                                                                                                   
drop1(c3, test="Chisq") #both species and SL significant 

plot(allEffects(c3))

#posthoc
library(multcomp)
posthoc<-glht(c5.2, linfct=mcp(species="Tukey"))
summary(posthoc)

drop1(c3, test="Chisq")                                                                                                    
c4 <- update(c3,.~.-SL)
drop1(c4, test="Chisq")                                                                                                    
c5 <- update(c4,.~.-species)
drop1(c5, test="Chisq")


c5.1 <- update(c5,.~.+rearlight)
KRmodcomp(c5.1,c5) # rearlight = 0.41

c5.2 <- update(c5,.~.+species)
KRmodcomp(c5.2,c5) # species = 0.10
plot(allEffects(c5.2))

c5.3 <- update(c5,.~.+SL)
KRmodcomp(c5.3,c5) # SL = 0.0.03


#####do eggspots differ in brightness?#####
hist(spots_rear$bright) #ok for lmer

slm1 <- lmer(bright ~rearlight*species+SL+(1|tag)+(1|momID)+(1|dadID)+(1|position)+(1|tank),data=spots_rear)
plot(slm1)
hist(resid(slm1)) #both spread and residuals seem ok for lmer
rand(slm1) #only tag needed, maybe position

slm1.1 <- lmer(bright ~rearlight*species+SL+(1|tag),data=spots_rear)
AIC(slm1, slm1.1)

drop1(slm1.1, test="Chisq")
slm2 <- update(slm1.1,.~.-rearlight:species)
drop1(slm2, test="Chisq")
slm3 <- update(slm2,.~.-species)
drop1(slm3, test="Chisq") 
slm4 <- update(slm3,.~.-rearlight)
drop1(slm4, test="Chisq")
slm5 <- update(slm4,.~.-SL)
drop1(slm5, test="Chisq")

KRmodcomp(slm4,slm5) #SL = 0.0018

slm5.1 <- update(slm5,.~.+rearlight)
KRmodcomp(slm5.1,slm5) #rearlight = 0.49

slm5.2 <- update(slm5,.~.+species)
KRmodcomp(slm5.2,slm5) #species = 0.08

posthoc<-glht(slm5.2, linfct=mcp(species="Tukey"))
summary(posthoc)

plot(allEffects(slm5.2))


#####Do spots differ in size - surface area?####
hist(spots_rear$tot.area) #total area faily normal
hist(spots_rear$lg.area) #so is largest spot, lmer for both

####total area first####
b1 <- lmer(tot.area ~rearlight*species+SL+(1|tag)+(1|momID)+(1|dadID)+(1|position)+(1|tank),data=spots_rear)
plot(b1)
rand(b1) #only tag needed

b1.1 <- lmer(tot.area ~rearlight*species+SL+(1|tag),data=spots_rear)
AIC(b1,b1.1)

plot(b1.1)
hist(resid(b1.1))

drop1(b1.1,test="Chisq") #all sigificant

plot(allEffects(b1.1))


spots_rear$inter <- interaction (spots_rear$rearlight,spots_rear$species)
b1.1a <- lmer(tot.area ~inter+SL+(1|tag),data=spots_rear)
library(multcomp)
posthoc<-glht(b1.1a, linfct=mcp(inter="Tukey"))
summary(posthoc)
#no differences, so drop interaction?

plot(allEffects(b1.1a))

b2 <- update(b1.1,.~.-rearlight:species)
drop1(b2,test="Chisq")
b3 <- update(b2,.~.-species)
drop1(b3,test="Chisq")
b4 <- update(b3,.~.-rearlight)
drop1(b4,test="Chisq") #only species sig
b5 <- update(b4,.~.-SL)

KRmodcomp(b4,b5) #SL = 0.0012

b5.1 <- update(b5,.~.+rearlight)
KRmodcomp(b5.1,b5) #rearlight = 0.98

b5.2 <- update(b5,.~.+species)
KRmodcomp(b5.2,b5) #species = 0.10

b5.3 <- update(b5,.~.+rearlight:species)
KRmodcomp(b5.3,b5) 

#biggest fish have a larger total area, but no other differences


####largest spot area####
b10 <- lmer(lg.area ~rearlight*species+SL+(1|tag)+(1|momID)+(1|dadID)+(1|position)+(1|tank),data=spots_rear)
plot(b10)
rand(b10) #only tag needed

b10.1 <- lmer(lg.area ~rearlight*species+SL+(1|tag),data=spots_rear)
AIC(b10,b10.1)

plot(b10.1)
hist(resid(b10.1))

drop1(b10.1,test="Chisq") #interaction trending

plot(allEffects(b10.1))


spots_rear$inter <- interaction (spots_rear$rearlight,spots_rear$species)
b1.1a <- lmer(tot.area ~inter+SL+(1|tag),data=spots_rear)
library(multcomp)
posthoc<-glht(b1.1a, linfct=mcp(inter="Tukey"))
summary(posthoc)
#no differences, so drop interaction?

plot(allEffects(b1.1a))

b12 <- update(b10.1,.~.-rearlight:species)
drop1(b12,test="Chisq")
b13 <- update(b12,.~.-SL)
drop1(b13,test="Chisq")
b14 <- update(b13,.~.-rearlight)
drop1(b14,test="Chisq") 
b15 <- update(b14,.~.-species)

KRmodcomp(b14,b15) #species = 0.194

b15.1 <- update(b15,.~.+rearlight)
KRmodcomp(b15.1,b15) #rearlight = 0.30

b15.2 <- update(b15,.~.+SL)
KRmodcomp(b15.2,b15) #SL = 0.27

#no differences in largest spot area



#####what about switched fish in Exp. 2?####
####first diffrences in colour####

spots_switch$fam <- as.factor(spots_switch$fam)
spots_switch$momID <- as.factor(spots_switch$momID)
spots_switch$dadID <- as.factor(spots_switch$dadID)
spots_switch$tag <- as.factor(spots_switch$tag)
spots_switch$tank <- as.factor(spots_switch$tank)
spots_switch$position <- as.factor(spots_switch$position)
spots_switch$rearlight <- as.factor(spots_switch$rearlight)
spots_switch$species <- as.factor(spots_switch$species)

fit <- prcomp(~spots_red + spots_orange + spots_yellow + spots_green + spots_blue + spots_magenta + spots_violet + spots_black, data=spots_switch, scale.=TRUE)
# with standardized mean 

summary(fit)
plot(fit) 
plot(fit,type="lines")
biplot(fit, scale =0)# biplot; scale = 0 insures arrows reflect loadings
fit$rotation #Loading matrix

#with only red, organe, yellow
fit1 <- prcomp(~spots_red + spots_orange + spots_yellow, data=spots_switch, scale.=TRUE)
# with standardized mean 

summary(fit1)
plot(fit1) 
plot(fit1,type="lines")
biplot(fit1, scale =0)# biplot; scale = 0 insures arrows reflect loadings
fit1$rotation #Loading matrix

#to add PC's to exisiting data frame for analysis
str(fit1)
spots_switch<-cbind(spots_switch,fit1$x)

write.csv(fit1$rotation, "/Users/dswright08/Desktop/spotsPC.csv")
write.csv(spots_switch, "/Users/dswright08/Desktop/spots_switch2.csv")

#In excel, calculated differences from mean PC values
#imported as new dataset, spots_switch2

spots_switch2$fam <- as.factor(spots_switch2$fam)
spots_switch2$momID <- as.factor(spots_switch2$momID)
spots_switch2$dadID <- as.factor(spots_switch2$dadID)
spots_switch2$tag <- as.factor(spots_switch2$tag)
spots_switch2$tank <- as.factor(spots_switch2$tank)
spots_switch2$position <- as.factor(spots_switch2$position)
spots_switch2$rearlight <- as.factor(spots_switch2$rearlight)
spots_switch2$treatment <- as.factor(spots_switch2$treatment)
spots_switch2$species <- as.factor(spots_switch2$species)

hist(spots_switch2$PC1)
hist(spots_switch2$PC2)


####Changes in PC1?####
#using lme to assess change over time
library(nlme)

sw1 <- lme(PC1~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
sw1a <- lme(PC1~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(sw1,sw1a) #without tank is better


sw1b <- lme(PC1~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID, ~1|dadID),control=lmeControl(opt = "optim"))
AIC(sw1a,sw1b) #without position is better

sw1c <- lme(PC1~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID),control=lmeControl(opt = "optim"))
AIC(sw1b,sw1c) #without dadID is better

sw1d <- lme(PC1~day*treatment*species, data=spots_switch2, random=list(~day|tag),control=lmeControl(opt = "optim"))
#will not work with only tag, so keeping momID

plot(ACF(sw1c),alpha=0.05)

sw1.1<-update(sw1c,correlation=corAR1())
plot(ACF(sw1.1),alpha=0.05)

anova(sw1c,sw1.1) #sw1c slightly better

sw1.2<-update(sw1c,correlation=corARMA(q=2))
sw1.3<-update(sw1c,correlation=corARMA(q=3))
anova(sw1c,sw1.2) 
anova(sw1c,sw1.3) #sw1c best

plot(sw1c)
qqnorm(sw1c,~resid(.)|tag)

sw1.ml <-update(sw1c,method="ML")

drop1(sw1.ml,test="Chisq")
sw2 <- update(sw1.ml,.~.-day:treatment:species)
drop1(sw2,test="Chisq")
sw3 <- update(sw2,.~.-day:species)
drop1(sw3,test="Chisq")
sw4 <- update(sw3,.~.-day:treatment)
drop1(sw4,test="Chisq")
sw5 <- update(sw4,.~.-treatment:species)
drop1(sw5,test="Chisq")
sw6 <- update(sw5,.~.-treatment)
drop1(sw6,test="Chisq")
sw7 <- update(sw6,.~.-species)
drop1(sw7,test="Chisq")
sw8 <- update(sw7,.~.-day)

#convert back to REML prior to final determination
sw8 <- update(sw8,method="REML")

sw8.1 <- update(sw8,.~.+treatment)
anova(sw8.1,test="Chisq") #treatment = 0.87

sw8.2 <- update(sw8,.~.+species)
anova(sw8.2,test="Chisq") #species = 0.81

sw8.3 <- update(sw8,.~.+day)
anova(sw8.3,test="Chisq") #day = 0.17

#NO differences in PC1


####Changes in PC2?####

sw10 <- lme(PC2~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
sw10a <- lme(PC2~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(sw10,sw10a) #without tank is better

sw10b <- lme(PC2~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID, ~1|dadID),control=lmeControl(opt = "optim"))
AIC(sw10a,sw10b) #with position is better

sw10c <- lme(PC2~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID,~1|position),control=lmeControl(opt = "optim"))
AIC(sw10a,sw10c) #without dadID is better

sw10d <- lme(PC2~day*treatment*species, data=spots_switch2, random=list(~day|tag,~1|position),control=lmeControl(opt = "optim"))
AIC(sw10c,sw10d) #without momID best

sw10e <- lme(PC2~day*treatment*species, data=spots_switch2, random=list(~day|tag),control=lmeControl(opt = "optim"))
AIC(sw10d,sw10e) #with position best

plot(ACF(sw10d),alpha=0.05)

sw10.1<-update(sw10d,correlation=corAR1())
plot(ACF(sw10.1),alpha=0.05)

anova(sw10d,sw10.1) #sw10d better

sw10.2<-update(sw10d,correlation=corARMA(q=2))
sw10.3<-update(sw10d,correlation=corARMA(q=3))
anova(sw10d,sw10.2)
anova(sw10d,sw10.3) #sw10d best

plot(sw10d)
qqnorm(sw10d,~resid(.)|tag)

sw10.ml <-update(sw10d,method="ML")

drop1(sw10.ml,test="Chisq")
sw12 <- update(sw10.ml,.~.-day:treatment:species)
drop1(sw12,test="Chisq")
sw13 <- update(sw12,.~.-day:treatment)
drop1(sw13,test="Chisq")
sw14 <- update(sw13,.~.-day:species)
drop1(sw14,test="Chisq")
sw15 <- update(sw14,.~.-treatment:species)
drop1(sw15,test="Chisq")
sw16 <- update(sw15,.~.-day)
drop1(sw16,test="Chisq")
sw17 <- update(sw16,.~.-treatment)
drop1(sw17,test="Chisq")
sw18 <- update(sw17,.~.-species)

#convert back to REML prior to final determination
sw18 <- update(sw18,method="REML")

sw18.1 <- update(sw18,.~.+treatment)
anova(sw18.1,test="Chisq") #treatment = 0.28

sw18.2 <- update(sw18,.~.+species)
anova(sw18.2,test="Chisq") #species = 0.02
plot(allEffects(sw18.2))

sw18.3 <- update(sw18,.~.+day)
anova(sw18.3,test="Chisq") #day = 0.78


####Changes in Brightness?####
hist(spots_switch2$bright)

sw20 <- lme(bright~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
sw20a <- lme(bright~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(sw20,sw20a) #without tank is better

sw20b <- lme(bright~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID, ~1|dadID),control=lmeControl(opt = "optim"))
AIC(sw20a,sw20b) #without position is better

sw20c <- lme(bright~day*treatment*species, data=spots_switch2, random=list(~day|tag, ~1|momID),control=lmeControl(opt = "optim"))
AIC(sw20b,sw20c) #without dadID is better

sw20d <- lme(bright~day*treatment*species, data=spots_switch2, random=list(~day|tag),control=lmeControl(opt = "optim"))
AIC(sw20c,sw20d) #wthout momID best

plot(ACF(sw20d),alpha=0.05)

sw20.1<-update(sw20d,correlation=corAR1())
plot(ACF(sw20.1),alpha=0.05)

anova(sw20d,sw20.1) #sw20d better

sw20.2<-update(sw20d,correlation=corARMA(q=2))
sw20.3<-update(sw20d,correlation=corARMA(q=3))
anova(sw20d,sw20.2)
anova(sw20d,sw20.3) #sw20d better

plot(sw20d)
qqnorm(sw20d,~resid(.)|tag)

sw20.ml <-update(sw20d,method="ML")

drop1(sw20.ml,test="Chisq")
sw22 <- update(sw20.ml,.~.-day:treatment:species)
drop1(sw22,test="Chisq")
sw23 <- update(sw22,.~.-treatment:species)
drop1(sw23,test="Chisq")
sw24 <- update(sw23,.~.-day:treatment)
drop1(sw24,test="Chisq")
sw25 <- update(sw24,.~.-day:species)
drop1(sw25,test="Chisq")
sw26 <- update(sw25,.~.-treatment)
drop1(sw26,test="Chisq")
sw27 <- update(sw26,.~.-species)
drop1(sw27,test="Chisq")
sw28 <- update(sw27,.~.-day)

#convert back to REML prior to final determination
sw28 <- update(sw28,method="REML")

sw28.1 <- update(sw28,.~.+treatment)
anova(sw28.1,test="Chisq") #treatment = 0.79

sw28.2 <- update(sw28,.~.+species)
anova(sw28.2,test="Chisq") #species = 0.73

sw28.3 <- update(sw28,.~.+day)
anova(sw28.3,test="Chisq") #day = 0.61

#NO differences in brightness

