#Analyses of colour between deep & shallow
#repeated (3) samples from each fish 
#PCA (including black)

library(MASS)
library(lme4)
library(ggplot2)
library(stats)
library(effects)
library(splines)
library(xlsx)
library(car)
library(lattice)
library(grid)
library(gridExtra)
library(pbkrtest)

str(rear3_all)

rear3_all$fam <- as.factor(rear3_all$fam)
rear3_all$momID <- as.factor(rear3_all$momID)
rear3_all$dadID <- as.factor(rear3_all$dadID)
rear3_all$tag <- as.factor(rear3_all$tag)
rear3_all$tank <- as.factor(rear3_all$tank)
rear3_all$position <- as.factor(rear3_all$position)

rear3_all$rearlight <- as.factor(rear3_all$rearlight)
rear3_all$species <- as.factor(rear3_all$species)
rear3_all$rear.env <- as.factor(rear3_all$rear.env)

rear3_all$fish_magenta <- rear3_all$fish_magneta

####Do the fish differ in total color?####
rear3_all$total <- (rear3_all$fish_black + rear3_all$fish_red + rear3_all$fish_orange + 
                      rear3_all$fish_yellow + rear3_all$fish_green + rear3_all$fish_blue +
                      rear3_all$fish_magenta + rear3_all$fish_violet)
table(rear3_all$total)
mean(rear3_all$total)
hist(rear3_all$total) #normal, can use lmer


#without black
rear3_all$total2 <- (rear3_all$fish_red + rear3_all$fish_orange + 
                      rear3_all$fish_yellow + rear3_all$fish_green + rear3_all$fish_blue +
                      rear3_all$fish_magenta + rear3_all$fish_violet)

table(rear3_all$total2)
mean(rear3_all$total2)
hist(rear3_all$total2) #normal, can use lmer


tot1 <- lmer(total ~ rearlight * species + SL +(1|tag)+(1|tank)+(1|position)+(1|momID)+(1|dadID), data=rear3_all)
plot(tot1)
rand(tot1) #only tag needed

tot1a <- lmer(total ~ rearlight * species + SL + (1|tag), data=rear3_all)
AIC(tot1,tot1a) #actually, tot1 is better given AIC

tot1b <- lmer(total ~ rearlight * species + SL + (1|tag) +(1|momID), data=rear3_all)
AIC(tot1,tot1b) #with tag & momID better
plot(tot1b)
summary(tot1b)

drop1(tot1b, test="Chisq")
tot2 <- update(tot1b,.~.-rearlight:species)
drop1(tot2, test="Chisq")
tot3 <- update(tot2,.~.-rearlight)
drop1(tot3, test="Chisq")
tot4 <- update(tot3,.~.-SL)
drop1(tot4, test="Chisq") 
tot5 <- update(tot4,.~.-species)

#NO differences in % colour coverage
KRmodcomp(tot4,tot5) #species = 0.29

tot5a <- update(tot5,.~.+rearlight)
KRmodcomp(tot5a,tot5) #rearlight = 0.57

tot5b <- update(tot5,.~.+SL)
KRmodcomp(tot5b,tot5) #SL = 0.43

#similiar results if black is excluded, all are ns.


####what about area that is not coloured?####
rear3_all$nc <- (100-rear3_all$total)
hist(rear3_all$nc)

tot10 <- lmer(nc ~ rearlight*species+SL+(1|tag)+(1|tank)+(1|position)+(1|momID)+(1|dadID),data=rear3_all)
plot(tot10)
rand(tot10) #only tag needed

tot10a <- lmer(nc ~ rearlight*species+SL+(1|tag),data=rear3_all)
plot(tot10a)
AIC(tot10,tot10a) #might need momID as well

tot10b <- lmer(nc ~ rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all)
plot(tot10b)
AIC(tot10,tot10b) #best with tag & momID


drop1(tot10b,test="Chisq")
tot11 <- update(tot10b,.~.-rearlight:species)
drop1(tot11,test="Chisq")
tot12 <- update(tot11,.~.-rearlight)
drop1(tot12,test="Chisq")
tot13 <- update(tot12,.~.-SL)
drop1(tot13,test="Chisq")
tot14 <- update(tot13,.~.-species)
drop1(tot14,test="Chisq")

#NO differences in 'other'color
KRmodcomp(tot13,tot14) #species = 0.29

tot14a <- update(tot14,.~.+rearlight)
KRmodcomp(tot14a,tot14) #rearlight = 0.57

tot14b <- update(tot14,.~.+SL)
KRmodcomp(tot14b,tot14) #SL = 0.43


####Principal components#####
#####whole fish#####

fit4 <- prcomp(~fish_red + fish_orange + fish_yellow + fish_green + fish_blue + fish_magenta + fish_violet + fish_black, data=rear3_all, scale.=TRUE)
# with standardized mean 

summary(fit4)
plot(fit4) 
plot(fit4,type="lines")
biplot(fit4, scale =0)# biplot; scale = 0 insures arrows reflect loadings
fit4$rotation #Loading matrix

fit4$center #mean of the variables
fit4$scale #standard deviation of the variables

#to add PC's to exisiting data frame for analysis
str(fit4)
rear3_all.f<-cbind(rear3_all,fit4$x)
str(rear3_all.f)

write.xlsx(fit4$rotation, "/Users/dswright08/Desktop/fit4.xlsx")


#####do fish differ in PC1####
q1 <- lmer(PC1~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.f)
rand(q1) #only tag, maybe momID needed

q1a <- lmer(PC1~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.f)
AIC(q1,q1a) 
rand(q1a) #momID not needed

q1b <- lmer(PC1~rearlight*species+SL+(1|tag),data=rear3_all.f)
AIC(q1a,q1b) 

plot(q1b)

drop1(q1b,test="Chisq")
q2 <- update(q1b,.~.-rearlight:species)
drop1(q2,test="Chisq")
q3 <- update(q2,.~.-rearlight)
drop1(q3,test="Chisq") #species sig, SL sig

summary(q3)
plot(allEffects(q3))

q4 <- update(q3,.~.-SL)
q4a <- update(q4,.~.-species)
q4b <- update(q4a,.~.+rearlight)

KRmodcomp(q4,q4a) #species < 0.001
plot(allEffects(q4))

q4c <- update(q4a,.~.+SL)
KRmodcomp(q4c,q4a) #SL = 0.17

KRmodcomp(q4b,q4a) #rearlight = 0.77

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(q3, linfct=mcp(species="Tukey"))
summary(posthoc)

rear3_all.f$species_f <- factor(rear3_all.f$species, levels=c('n','h','p'))

ggplot(rear3_all.f,aes(x=species_f,y=PC1,colour=species_f))+
  geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("red2","forestgreen","mediumblue"))+
  scale_x_discrete(name="", labels=c("P.nye","Hybrid","P.pun"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC1")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


#####do fish differ in PC2####
q5 <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID), data=rear3_all.f)
rand(q5) #tag and momID needed

q5a <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.f)
AIC(q5,q5a) 
rand(q5a)

plot(q5a)

drop1(q5a,test="Chisq")
q6 <- update(q5a,.~.-rearlight:species)
drop1(q6,test="Chisq")
q7 <- update(q6,.~.-species)
drop1(q7,test="Chisq")
q8 <- update(q7,.~.-SL)
drop1(q8,test="Chisq") #only rearlight sig
q9 <- update(q8,.~.-rearlight)
drop1(q9,test="Chisq")

summary(q8)
plot(allEffects(q8)) #fish in deep higher for PC2

q9a <- update(q9,.~.+species)
q9b <- update(q9,.~.+SL)

KRmodcomp(q8,q9) #rearlight = 0.004
KRmodcomp(q9a,q9) #species = 0.55
KRmodcomp(q9b,q9) #SL = 0.64

ggplot(rear3_all.f,aes(x=species_f,y=PC2,colour=species_f))+
  geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("red2","forestgreen","mediumblue"))+
  scale_x_discrete(name="", labels=c("P.nye","Hybrid","P.pun"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC2")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))

ggplot(rear3_all.f,aes(x=rearlight,y=PC2,colour=rearlight))+geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-1, 1))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("orangered2","deepskyblue3"))+
  scale_x_discrete(name="Rearing light", labels=c("Deep","Shallow"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC2")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


#####do fish differ in PC3####
q10 <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.f)
rand(q10) #only tag, maybe momID

q10a <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.f)
AIC(q10,q10a) 
rand(q10a)

plot(q10a)

drop1(q10a,test="Chisq") #interaction is sig, removing SL
q11 <- update(q10a,.~.-SL)
drop1(q11,test="Chisq")

plot(allEffects(q11))

#posthoc testing using multcomp
rear3_all.f$inter <- interaction (rear3_all.f$rearlight,rear3_all.f$species)
q11a <- lmer(PC3~inter+(1|tag)+(1|momID),data=rear3_all.f)
library(multcomp)
posthoc<-glht(q11a, linfct=mcp(inter="Tukey"))
summary(posthoc)
#No within species differences

ggplot(rear3_all.f,aes(x=species_f,y=PC3,colour=species_f))+
  geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("red2","forestgreen","mediumblue"))+
  scale_x_discrete(name="", labels=c("P.nye","Hybrid","P.pun"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC3")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))

q12 <- update(q11,.~.-rearlight:species)
drop1(q12,test="Chisq")
q13 <- update(q12,.~.-rearlight)
drop1(q13,test="Chisq") #only species (0.021)
q14 <- update(q13,.~.-species)
drop1(q14,test="Chisq")

q14a <- update(q14,.~.+rearlight)
q14b <- update(q14,.~.+SL)

KRmodcomp(q13,q14) #speices = 0.051
KRmodcomp(q14a,q14) #rearlight = 0.74
KRmodcomp(q14b,q14) #SL = 0.50

plot(allEffects(q13)) #N slightly higher PC3

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(q13, linfct=mcp(species="Tukey"))
summary(posthoc)


#####do fish differ in PC4####
q15 <- lmer(PC4~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.f)
rand(q15) #only tag needed

q15a <- lmer(PC4~rearlight*species+SL+(1|tag),data=rear3_all.f)
AIC(q15,q15a) 
rand(q15a)

plot(q15a)

drop1(q15a,test="Chisq")
q16 <- update(q15a,.~.-rearlight:species)
drop1(q16,test="Chisq")
q17 <- update(q16,.~.-rearlight)
drop1(q17,test="Chisq") 
q18 <- update(q17,.~.-species)
drop1(q18,test="Chisq") 
q19 <- update(q18,.~.-SL)
drop1(q19,test="Chisq")

plot(allEffects(q18))
#smaller fisher are higher in PC4

q19a <- update(q19,.~.+species)
q19b <- update(q19,.~.+rearlight)

KRmodcomp(q18,q19) #SL = 0.03
KRmodcomp(q19a,q19) #species = 0.09
KRmodcomp(q19b,q19) #rearlight = 0.59

plot(allEffects(q19a))

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(q19a, linfct=mcp(species="Tukey"))
summary(posthoc)

ggplot(rear3_all.f,aes(x=species_f,y=PC4,colour=species_f))+
  geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("red2","forestgreen","mediumblue"))+
  scale_x_discrete(name="", labels=c("P.nye","Hybrid","P.pun"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC4")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


####now what about body colour differences####

fit5 <- prcomp(~body_red + body_orange + body_yellow + body_green + body_blue + body_magenta + body_violet + body_black, data=rear3_all, scale.=TRUE)
# with standardized mean 

summary(fit5)
plot(fit5) 
biplot(fit5, scale =0)# biplot; scale = 0 insures arrows reflect loadings
fit5$rotation #Loading matrix

fit5$center #mean of the variables
fit5$scale #standard deviation of the variables

#to add PC's to exisiting data frame for analysis
str(fit5)
rear3_all.b<-cbind(rear3_all,fit5$x)

write.xlsx(fit5$rotation, "/Users/dswright08/Desktop/fit5.xlsx")


#####do bodies differ in PC1####
qb1 <- lmer(PC1~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.b)
rand(qb1) #only tag needed

qb1a <- lmer(PC1~rearlight*species+SL+(1|tag),data=rear3_all.b)
AIC(qb1,qb1a) 
rand(qb1a)

plot(qb1a)

drop1(qb1a,test="Chisq")
qb2 <- update(qb1a,.~.-rearlight:species)
drop1(qb2,test="Chisq")
qb3 <- update(qb2,.~.-rearlight)
drop1(qb3,test="Chisq") 

plot(allEffects(qb3)) #both SL and species sig

qb4 <- update(qb3,.~.-SL)
drop1(qb4,test="Chisq")
qb4a <- update(qb4,.~.-species)

qb4b <- update(qb4a,.~.+SL)
qb4c <- update(qb4a,.~.+rearlight)

KRmodcomp(qb4,qb4a) #species < 0.0001
KRmodcomp(qb4b,qb4a) #SL = 0.326
KRmodcomp(qb4c,qb4a) #rearlight = 0.74

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qb4, linfct=mcp(species="Tukey"))
summary(posthoc)

ggplot(rear3_all.b,aes(x=species,y=PC1,colour=species))+geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("green","red","blue"))+
  scale_x_discrete(name="", labels=c("Hybrid","P.nye","P.pun"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC1")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


#####do bodies differ in PC2####
qb5 <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.b)
rand(qb5) #tag and momID needed

qb5a <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.b)
AIC(qb5,qb5a) 
rand(qb5a)

plot(qb5a)

drop1(qb5a,test="Chisq")
qb6 <- update(qb5a,.~.-rearlight:species)
drop1(qb6,test="Chisq")
qb7 <- update(qb6,.~.-SL)
drop1(qb7,test="Chisq") #rearlight (0.02) & species (0.013)
qb8 <- update(qb7,.~.-rearlight)
drop1(qb8,test="Chisq")
qb9 <- update(qb8,.~.-species)
drop1(qb9,test="Chisq")

plot(allEffects(qb7)) #again N highest, deep higher

qb9a <- update(qb9,.~.+SL)
qb9b <- update(qb9,.~.+rearlight)

KRmodcomp(qb8,qb9) #species = 0.035
KRmodcomp(qb9a,qb9) #SL = 0.27
KRmodcomp(qb9b,qb9) #rearlight = 0.0327

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qb8, linfct=mcp(species="Tukey"))
summary(posthoc)

ggplot(rear3_all.b,aes(x=rearlight,y=PC2,colour=rearlight))+geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-1, 1))+ 
  stat_smooth(data=rear3_all.b,aes(rearlight,PC2,colour=rearlight,group=rearlight),se=FALSE,size=0.8,
  show.legend = F)+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("orangered2","deepskyblue3"))+
  scale_y_continuous(name="Body PC2")+
  scale_x_discrete(name="") +
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


#####do bodies differ in PC3####
qb10 <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.b)
rand(qb10) #tag and momID needed

qb10a <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.b)
AIC(qb10,qb10a) 
rand(qb10a)

plot(qb10a)

drop1(qb10a,test="Chisq") #trending interaction
qb11 <- update(qb10a,.~.-SL) 
drop1(qb11,test="Chisq") #trending

plot(allEffects(qb11))

#posthoc testing using multcomp
rear3_all.b$inter <- interaction (rear3_all.b$rearlight,rear3_all.b$species)
qb11a <- lmer(PC3~inter+(1|tag)+(1|momID),data=rear3_all.b)
library(multcomp)
posthoc<-glht(qb11a, linfct=mcp(inter="Tukey"))
summary(posthoc)
#No significant differences

qb12 <- update(qb11,.~.-rearlight:species)
drop1(qb12,test="Chisq")
qb13 <- update(qb12,.~.-species)
drop1(qb13,test="Chisq") 
qb14 <- update(qb13,.~.-rearlight)
drop1(qb14,test="Chisq")

#NO differences in body PC3

qb14a <- update(qb14,.~.+SL)
qb14b <- update(qb14,.~.+species)

KRmodcomp(qb13,qb14) #rearlight = 0.23
KRmodcomp(qb14a,qb14) #SL = 0.88
KRmodcomp(qb14b,qb14) #species = 0.35

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qb14b, linfct=mcp(species="Tukey"))
summary(posthoc)


#####do bodies differ in PC4####
qb15 <- lmer(PC4~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.b)
rand(qb15) #only tag needed

qb15a <- lmer(PC4~rearlight*species+SL+(1|tag),data=rear3_all.b)
AIC(qb15,qb15a)
rand(qb15a)

plot(qb15a)

drop1(qb15a,test="Chisq")
qb16 <- update(qb15a,.~.-rearlight:species)
drop1(qb16,test="Chisq")
qb17 <- update(qb16,.~.-species)
drop1(qb17,test="Chisq") 
qb18 <- update(qb17,.~.-SL)
drop1(qb18,test="Chisq") #rearlight trending
qb19 <- update(qb18,.~.-rearlight)
drop1(qb19,test="Chisq")

plot(allEffects(qb18)) 
#shallow higher in PC4

qb19a <- update(qb19,.~.+SL)
qb19b <- update(qb19,.~.+species)

KRmodcomp(qb18,qb19) #rearlight = 0.057
KRmodcomp(qb19a,qb19) #SL = 0.069
KRmodcomp(qb19b,qb19) #species = 0.20

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qb19b, linfct=mcp(species="Tukey"))
summary(posthoc)

ggplot(rear3_all.b,aes(x=rearlight,y=PC4,colour=rearlight))+geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-1, 1))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("green","red","blue"))+
  scale_x_discrete(name="", labels=c("Deep","Shallow"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC4")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


####now what about dorsal colour differences####

fit6 <- prcomp(~dorsal_red + dorsal_orange + dorsal_yellow + dorsal_green + dorsal_blue + dorsal_magenta + dorsal_violet + dorsal_black, data=rear3_all, scale.=TRUE)
# with standardized mean 

summary(fit6)
plot(fit6) 
biplot(fit6, scale =0)# biplot; scale = 0 insures arrows reflect loadings
fit6$rotation #Loading matrix

fit6$center #mean of the variables
fit6$scale #standard deviation of the variables

#to add PC's to exisiting data frame for analysis
str(fit6)
rear3_all.d<-cbind(rear3_all,fit6$x)

write.xlsx(fit6$rotation, "/Users/dswright08/Desktop/fit6.xlsx")


#####do dorsal differ in PC1####
qd1 <- lmer(PC1~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.d)
rand(qd1) #only tag needed

qd1a <- lmer(PC1~rearlight*species+SL+(1|tag),data=rear3_all.d)
AIC(qd1,qd1a) 
rand(qd1a)

plot(qd1a)

drop1(qd1a,test="Chisq") 
qd2 <- update(qd1b,.~.-rearlight:species)
drop1(qd2,test="Chisq")
qd3 <- update(qd2,.~.-SL)
drop1(qd3,test="Chisq") 
qd4 <- update(qd3,.~.-rearlight)
drop1(qd4,test="Chisq") #species highly sig
qd4a <- update(qd4,.~.-species)
drop1(qd4a,test="Chisq")

summary(qd4)
plot(allEffects(qd4)) #N highest, P lowest

qd4b <- update(qd4a,.~.+SL)
qd4c <- update(qd4a,.~.+rearlight)

KRmodcomp(qd4,qd4a) #species < 0.0001
KRmodcomp(qd4b,qd4a) #SL = 0.17
KRmodcomp(qd4c,qd4a) #rearlight = 0.87

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qd4, linfct=mcp(species="Tukey"))
summary(posthoc)


ggplot(rear3_all.d,aes(x=species,y=PC1,colour=species))+geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("green","red","blue"))+
  scale_x_discrete(name="", labels=c("Hybrid","P.nye","P.pun"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC1")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


#####do dorsal differ in PC2####
qd5 <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.d)
rand(qd5) #tag and momID

qd5a <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.d)
AIC(qd5,qd5a) 
rand(qd5a)

plot(qd5a)

drop1(qd5a,test="Chisq")
qd6 <- update(qd5a,.~.-rearlight:species)
drop1(qd6,test="Chisq")
qd7 <- update(qd6,.~.-species)
drop1(qd7,test="Chisq") 
qd8 <- update(qd7,.~.-rearlight)
drop1(qd8,test="Chisq") 
qd9 <- update(qd8,.~.-SL)
drop1(qd9,test="Chisq") 

#NO differences in dorsal PC2

qd9b <- update(qd9,.~.+species)
qd9c <- update(qd9,.~.+rearlight)

KRmodcomp(qd8,qd9) #SL = 0.24
KRmodcomp(qd9b,qd9) #species = 0.74
KRmodcomp(qd9c,qd9) #rearlight = 0.43


#####do dorsal differ in PC3####
qd10 <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.d)
rand(qd10) #tag, momID, dadID, and tank needed

qd10a <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.d)
AIC(qd10,qd10a) 
rand(qd10a)

plot(qd10a)

drop1(qd10a,test="Chisq")
qd11 <- update(qd10a,.~.-rearlight:species) 
drop1(qd11,test="Chisq")
qd12 <- update(qd11,.~.-rearlight)
drop1(qd12,test="Chisq")
qd13 <- update(qd12,.~.-SL)
drop1(qd13,test="Chisq") #species trending 0.087
qd14 <- update(qd13,.~.-species)
drop1(qd14,test="Chisq")

plot(allEffects(qd13)) #H lower in  PC3

qd14b <- update(qd14,.~.+SL)
qd14c <- update(qd14,.~.+rearlight)

KRmodcomp(qd13,qd14) #species = 0.15
KRmodcomp(qd14b,qd14) #SL = 0.89
KRmodcomp(qd14c,qd14) #rearlight = 0.99

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qd13, linfct=mcp(species="Tukey"))
summary(posthoc)

#####do dorsal differ in PC4####
qd15 <- lmer(PC4~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.d)
rand(qd15) #tag and momID needed

qd15a <- lmer(PC4~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.d)
AIC(qd15,qd15a) 
rand(qd15a)

plot(qd15a)

drop1(qd15a,test="Chisq")
qd16 <- update(qd15a,.~.-rearlight:species)
drop1(qd16,test="Chisq")
qd17 <- update(qd16,.~.-SL)
drop1(qd17,test="Chisq") 
qd18 <- update(qd17,.~.-rearlight)
drop1(qd18,test="Chisq") 
qd19 <- update(qd18,.~.-species)
drop1(qd19,test="Chisq")

#NO differences in PC4

qd19b <- update(qd19,.~.+SL)
qd19c <- update(qd19,.~.+rearlight)

KRmodcomp(qd18,qd19) #species = 0.22
KRmodcomp(qd19b,qd19) #SL = 0.77
KRmodcomp(qd19c,qd19) #rearlight = 0.28

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qd18, linfct=mcp(species="Tukey"))
summary(posthoc)


####now what about anal fin colour differences####

fit7 <- prcomp(~anal_red + anal_orange + anal_yellow + anal_green + anal_blue + anal_magenta + anal_violet + anal_black, data=rear3_all, scale.=TRUE)
# with standardized mean 

summary(fit7)
plot(fit7) 
biplot(fit7, scale =0)# biplot; scale = 0 insures arrows reflect loadings
fit7$rotation #Loading matrix

fit7$center #mean of the variables
fit7$scale #standard deviation of the variables

#to add PC's to exisiting data frame for analysis
str(fit7)
rear3_all.a<-cbind(rear3_all,fit7$x)

write.xlsx(fit7$rotation, "/Users/dswright08/Desktop/fit7.xlsx")


#####do anal fins differ in PC1####
qa1 <- lmer(PC1~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.a)
rand(qa1) #tag and momID needed

qa1a <- lmer(PC1~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.a)
AIC(qa1,qa1a) 
rand(qa1a)

plot(qa1a)

drop1(qa1a,test="Chisq") 
qa2 <- update(qa1a,.~.-rearlight:species)
drop1(qa2,test="Chisq")
qa3 <- update(qa2,.~.-rearlight)
drop1(qa3,test="Chisq") 
qa4 <- update(qa3,.~.-SL)
drop1(qa4,test="Chisq") #species  sig
qa4a <- update(qa4,.~.-species)
drop1(qa4a,test="Chisq")

summary(qa4)
plot(allEffects(qa4)) #N lowest, H highest

qa4b <- update(qa4a,.~.+SL)
qa4c <- update(qa4a,.~.+rearlight)

KRmodcomp(qa4,qa4a) #species = 0.08
KRmodcomp(qa4b,qa4a) #SL = 0.07
KRmodcomp(qa4c,qa4a) #rearlight = 0.22

ggplot(rear3_all.a,aes(x=species,y=PC1,colour=species))+geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("green","red","blue"))+
  scale_x_discrete(name="", labels=c("Hybrid","P.nye","P.pun"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC1")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


#####do anal fins differ in PC2####
qa5 <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.a)
rand(qa5) #tag, momID needed

qa5a <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.a)
AIC(qa5,qa5a) 
rand(qa5a)

plot(qa5a)

drop1(qa5a,test="Chisq")
qa6 <- update(qa5a,.~.-rearlight:species)
drop1(qa6,test="Chisq")
qa7 <- update(qa6,.~.-rearlight)
drop1(qa7,test="Chisq") 
qa8 <- update(qa7,.~.-SL)
drop1(qa8,test="Chisq") 
qa9 <- update(qa8,.~.-species)
drop1(qa9,test="Chisq") 

#NO differences in anal PC2

qa9b <- update(qa9,.~.+SL)
qa9c <- update(qa9,.~.+rearlight)

KRmodcomp(qa8,qa9) #species = 0.39
KRmodcomp(qa9b,qa9) #SL = 0.47
KRmodcomp(qa9c,qa9) #rearlight = 0.62

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qa8, linfct=mcp(species="Tukey"))
summary(posthoc)


#####do anal fins differ in PC3####
qa10 <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.a)
rand(qa10) #only tag needed

qa10a <- lmer(PC3~rearlight*species+SL+(1|tag),data=rear3_all.a)
AIC(qa10,qa10a) 
rand(qa10a)

plot(qd10a)

drop1(qa10a,test="Chisq")
qa11 <- update(qa10a,.~.-rearlight:species) 
drop1(qa11,test="Chisq")
qa12 <- update(qa11,.~.-rearlight)
drop1(qa12,test="Chisq")
qa13 <- update(qa12,.~.-SL)
drop1(qa13,test="Chisq") #species sig 0.0019
qa14 <- update(qa13,.~.-species)
drop1(qa14,test="Chisq")

plot(allEffects(qa13)) #N lower in  PC3

qa14b <- update(qa14,.~.+SL)
qa14c <- update(qa14,.~.+rearlight)

KRmodcomp(qa13,qa14) #species = 0.002
KRmodcomp(qa14b,qa14) #SL = 0.81
KRmodcomp(qa14c,qa14) #rearlight = 0.49

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qa13, linfct=mcp(species="Tukey"))
summary(posthoc)


#####do anal fins differ in PC4####
qa15 <- lmer(PC4~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.a)
rand(qa15) #tag, momID needed

qa15a <- lmer(PC4~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.a)
AIC(qa15,qa15a) 
rand(qa15a)

plot(qa15a)

drop1(qa15a,test="Chisq")
qa16 <- update(qa15a,.~.-rearlight:species)
drop1(qa16,test="Chisq")
qa17 <- update(qa16,.~.-SL)
drop1(qa17,test="Chisq") 
qa18 <- update(qa17,.~.-rearlight)
drop1(qa18,test="Chisq") #species trending = 0.06
qa19 <- update(qa18,.~.-species)
drop1(qa19,test="Chisq")

plot(allEffects(qa18)) #P higher in PC4

qa19b <- update(qa19,.~.+SL)
qa19c <- update(qa19,.~.+rearlight)

KRmodcomp(qa18,qa19) #species = 0.11
KRmodcomp(qa19b,qa19) #SL = 0.97
KRmodcomp(qa19c,qa19) #rearlight = 0.80

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qa18, linfct=mcp(species="Tukey"))
summary(posthoc)



####now what about caudal fin colour differences####
####with all colours####

fit8 <- prcomp(~tail_red + tail_orange + tail_yellow + tail_green + tail_blue + tail_magenta + tail_violet + tail_black, data=rear3_all, scale.=TRUE)
# with standardized mean 

summary(fit8)
plot(fit8) 
biplot(fit8, scale =0)# biplot; scale = 0 insures arrows reflect loadings
fit8$rotation #Loading matrix

fit8$center #mean of the variables
fit8$scale #standard deviation of the variables

#to add PC's to exisiting data frame for analysis
str(fit8)
rear3_all.t<-cbind(rear3_all,fit8$x)

write.xlsx(fit8$rotation, "/Users/dswright08/Desktop/fit8.xlsx")


#####do caudal fins differ in PC1####
qt1 <- lmer(PC1~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.t)
rand(qt1) #only tag needed

qt1a <- lmer(PC1~rearlight*species+SL+(1|tag),data=rear3_all.t)
AIC(qt1,qt1a)
rand(qt1a)

plot(qt1a)

drop1(qt1a,test="Chisq")
qt2 <- update(qt1a,.~.-rearlight:species)
drop1(qt2,test="Chisq")
qt3 <- update(qt2,.~.-rearlight)
drop1(qt3,test="Chisq") 

plot(allEffects(qt3)) #species & SL sig

qt4 <- update(qt3,.~.-species)
drop1(qt4,test="Chisq") #SL  sig (0.005)
qt4a <- update(qt4,.~.-SL)
drop1(qt4a,test="Chisq")

summary(qt4)
plot(allEffects(qt4)) #smaller fish higher PC1

qt4b <- update(qt4a,.~.+species)
qt4c <- update(qt4a,.~.+rearlight)

KRmodcomp(qt4,qt4a) #SL = 0.0005
KRmodcomp(qt4b,qt4a) #species = 0.01
KRmodcomp(qt4c,qt4a) #rearlight = 0.93

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qt3, linfct=mcp(species="Tukey"))
summary(posthoc)
#P sig higher than N in PC1, no diff with H


ggplot(rear3_all.t,aes(x=species,y=PC1,colour=species))+geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("green","red","blue"))+
  scale_x_discrete(name="", labels=c("Hybrid","P.nye","P.pun"),expand = c(0,0.7)) + 
  scale_y_continuous(name="PC1")+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


#####do caudal fins differ in PC2####
qt5 <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.t)
rand(qt5) #only tag, tank needed

qt5a <- lmer(PC2~rearlight*species+SL+(1|tag)+(1|tank),data=rear3_all.t)
AIC(qt5,qt5a) 
rand(qt5a)

plot(qt5a) #not the best spread??
hist(resid(qt5a)) #strong peak, but more or less normal

drop1(qt5a,test="Chisq")
qt6 <- update(qt5a,.~.-rearlight:species)
drop1(qt6,test="Chisq") #all single parameters are sig
plot(allEffects(qt6))

qt7 <- update(qt6,.~.-rearlight)
drop1(qt7,test="Chisq") 
qt8 <- update(qt7,.~.-SL)
drop1(qt8,test="Chisq") 
qt9 <- update(qt8,.~.-species)
drop1(qt9,test="Chisq") 

qt9b <- update(qt9,.~.+SL)
qt9c <- update(qt9,.~.+rearlight)

KRmodcomp(qt8,qt9) #species < 0.0001
KRmodcomp(qt9b,qt9) #SL = 0.078
KRmodcomp(qt9c,qt9) #rearlight = 0.083

plot(allEffects(qt8))

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qt8, linfct=mcp(species="Tukey"))
summary(posthoc)

ggplot(rear3_all.t,aes(x=rearlight,y=PC2,colour=rearlight))+geom_hline(yintercept=0,colour="gray88",size=1)+
  coord_cartesian(ylim=c(-1, 1))+ 
  stat_smooth(data=rear3_all.t,aes(rearlight,PC2,colour=rearlight,group=rearlight),se=FALSE,size=0.8,
  show.legend = F)+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("orangered2","deepskyblue3"))+
  scale_y_continuous(name="Caudal PC2")+
  scale_x_discrete(name="") +
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1,"lines"))


#####do caudal fins differ in PC3####
qt10 <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.t)
rand(qt10) #only tag needed

qt10a <- lmer(PC3~rearlight*species+SL+(1|tag),data=rear3_all.t)
AIC(qt10,qt10a) #actually, qt10 is better given AIC

qt10b <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|position)+(1|momID)+(1|dadID),data=rear3_all.t)
AIC(qt10,qt10b)
rand(qt10b)

qt10c <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|momID)+(1|dadID),data=rear3_all.t)
AIC(qt10b,qt10c) 

qt10d <- lmer(PC3~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all.t)
AIC(qt10c,qt10d) #without dadID is better

qt10e <- lmer(PC3~rearlight*species+SL+(1|tag),data=rear3_all.t)
AIC(qt10d,qt10e) #with momID is best

rand(qt10d)

plot(qt10d)

drop1(qt10d,test="Chisq")
qt11 <- update(qt10d,.~.-rearlight:species) 
drop1(qt11,test="Chisq")
qt12 <- update(qt11,.~.-rearlight)
drop1(qt12,test="Chisq")
qt13 <- update(qt12,.~.-SL)
drop1(qt13,test="Chisq") 
qt14 <- update(qt13,.~.-species)
drop1(qt14,test="Chisq")

qt14b <- update(qt14,.~.+SL)
qt14c <- update(qt14,.~.+rearlight)

KRmodcomp(qt13,qt14) #species = 0.38
KRmodcomp(qt14b,qt14) #SL = 0.43
KRmodcomp(qt14c,qt14) #rearlight = 0.80

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qt13, linfct=mcp(species="Tukey"))
summary(posthoc)


#####do caudal fins differ in PC4####
qt15 <- lmer(PC4~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.t)
rand(qt15) #only tag needed

qt15a <- lmer(PC4~rearlight*species+SL+(1|tag),data=rear3_all.t)
AIC(qt15,qt15a) 
rand(qt15a)

plot(qt15a)

drop1(qt15a,test="Chisq")
qt16 <- update(qt15a,.~.-rearlight:species)
drop1(qt16,test="Chisq")
qt17 <- update(qt16,.~.-rearlight)
drop1(qt17,test="Chisq") #species is trending
qt18 <- update(qt17,.~.-species)
drop1(qt18,test="Chisq") #SL sig <0.0001
qt19 <- update(qt18,.~.-SL)
drop1(qt19,test="Chisq")

plot(allEffects(qt18)) #smaller fish higher in PC4

qt19b <- update(qt19,.~.+species)
qt19c <- update(qt19,.~.+rearlight)

KRmodcomp(qt18,qt19) #SL < 0.0001
KRmodcomp(qt19b,qt19) #species = 0.009
KRmodcomp(qt19c,qt19) #rearlight = 0.67

plot(allEffects(qt19b))

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(qt19b, linfct=mcp(species="Tukey"))
summary(posthoc)


#####do fish differ in brightness?#####
#measured in photoshop

hist(rear3_all$bright) #normal

lm1 <- lmer(bright ~rearlight*species+SL+(1|tag)+(1|momID)+(1|dadID)+(1|position)+(1|tank),data=rear3_all)
plot(lm1)
hist(resid(lm1)) #both spread and residuals seem ok for lmer
rand(lm1) #only tag, momID needed

lm1.1 <- lmer(bright ~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all)
plot(lm1.1)
AIC(lm1,lm1.1)
rand(lm1.1) #momID iffy

lm1.2 <- lmer(bright~rearlight*species+SL+(1|tag),data=rear3_all)
AIC(lm1.1,lm1.2) #without momID is better (although AIC is slightly higher)
plot(lm1.2)

drop1(lm1.2,test="Chisq")
lm2 <- update(lm1.2,.~.-rearlight:species)
drop1(lm2,test="Chisq")
lm3 <- update(lm2,.~.-rearlight)
drop1(lm3,test="Chisq") #species is trending

plot(allEffects(lm3))
posthoc<-glht(lm3, linfct=mcp(species="Tukey"))
summary(posthoc)

lm4 <- update(lm3,.~.-species)
drop1(lm4,test="Chisq") #only SL sig

plot(allEffects(lm4))
#smaller fish have higher brightness

drop1(lm4,test="Chisq")
lm5 <- update(lm4,.~.-SL)

KRmodcomp(lm4,lm5) #SL = 0.0013
plot(allEffects(lm4))

lm5.1 <- update(lm5,.~.+rearlight)
KRmodcomp(lm5.1,lm5) #rearlight = 0.43

lm5.2 <- update(lm5,.~.+species)
KRmodcomp(lm5.2,lm5) #species = 0.08
plot(allEffects(lm5.2))
posthoc<-glht(lm5.2, linfct=mcp(species="Tukey"))
summary(posthoc)

#only an SL effect on brightness (species is trending)


#####Do fish differ in size?#####

hist((rear3_all.1$SL)) #only 1 observation per individual, using only day 1

sl1 <- lm(SL~species, data=rear3_all.1)
anova(sl1,test="Chisq")
summary(sl1)

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(sl1, linfct=mcp(species="Tukey"))
summary(posthoc)
plot(allEffects(sl1))



#####What about Nat vs. Unnat rearing?#####
#remove hybrids
rear3_all.f.np <- rear3_all.f[-which(rear3_all.f$species=='h'),]

####PC1####
n1 <- lmer(PC1~rear.env*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.f.np)
rand(n1) #only tag, momID needed

n1.1 <- lmer(PC1~rear.env*species+SL+(1|tag)+(1|momID),data=rear3_all.f.np)
rand(n1.1)

AIC(n1,n1.1)
plot(n1.1)

drop1(n1.1,test="Chisq")
n2 <- update(n1.1,.~.-rear.env:species)
drop1(n2,test="Chisq")
n3 <- update(n2,.~.-rear.env)
drop1(n3,test="Chisq")
n4 <- update(n3,.~.-SL)
drop1(n4,test="Chisq")

#same result as before - rear.env no effect
#species differences (as above)


####PC2####
n10 <- lmer(PC2~rear.env*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.f.np)
rand(n10) #only tag, momID needed

n10.1 <- lmer(PC2~rear.env*species+SL+(1|tag)+(1|momID),data=rear3_all.f.np)
rand(n10.1)

AIC(n10,n10.1)
plot(n10.1)

drop1(n10.1,test="Chisq") #trending interaction
plot(allEffects(n10.1))
#N are generally higher, but nothing with environment

n12 <- update(n10.1,.~.-rear.env:species)
drop1(n12,test="Chisq")
n13 <- update(n12,.~.-SL)
drop1(n13,test="Chisq")
n14 <- update(n13,.~.-rear.env)
drop1(n14,test="Chisq")

#same result as before - rear.env no effect


####PC3####
n20 <- lmer(PC3~rear.env*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.f.np)
rand(n20) #only tag, momID needed

n20.1 <- lmer(PC3~rear.env*species+SL+(1|tag)+(1|momID),data=rear3_all.f.np)
rand(n20.1)

AIC(n20,n20.1)
plot(n20.1)

drop1(n20.1,test="Chisq") #trending interaction
plot(allEffects(n20.1))
#again, N is higher, but no within species differences

n22 <- update(n20.1,.~.-rear.env:species)
drop1(n22,test="Chisq")
n23 <- update(n22,.~.-SL)
drop1(n23,test="Chisq") #species and rear.env sig
plot(allEffects(n23))

#N higher in PC3
#Natural rearing higher in PC3 - not so informative?


####PC4####
n30 <- lmer(PC4~rear.env*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all.f.np)
rand(n30) #only tag

n30.1 <- lmer(PC4~rear.env*species+SL+(1|tag),data=rear3_all.f.np)
rand(n30.1)

AIC(n30,n30.1)
plot(n30.1)

drop1(n30.1,test="Chisq") 
n32 <- update(n30.1,.~.-rear.env:species)
drop1(n32,test="Chisq")
n33 <- update(n32,.~.-rear.env)
drop1(n33,test="Chisq")
n34 <- update(n33,.~.-SL)
drop1(n34,test="Chisq")
plot(allEffects(n34))

#same result as before - rear.env no effect
#trending species effect, N somewhat higher





