#Analyses of individual colours between deep & shallow
#repeated (3) samples from each fish 

library(MASS)
library(lme4)
library(ggplot2)
library(stats)
library(effects)
library(splines)
library(xlsx)
library(car)
library(lattice)
library(grid)
library(gridExtra)
library(pbkrtest)

str(rear3_all)

rear3_all$fam <- as.factor(rear3_all$fam)
rear3_all$momID <- as.factor(rear3_all$momID)
rear3_all$dadID <- as.factor(rear3_all$dadID)
rear3_all$tag <- as.factor(rear3_all$tag)
rear3_all$tank <- as.factor(rear3_all$tank)
rear3_all$position <- as.factor(rear3_all$position)

rear3_all$rearlight <- as.factor(rear3_all$rearlight)
rear3_all$species <- as.factor(rear3_all$species)

rear3_all$fish_magenta <- rear3_all$fish_magneta #total fish magenta spelled wrong in dataset

#plot of total fish by colour
ggplot(rear3_all,aes(x=rearlight,y=fish_red,color=rearlight))+geom_boxplot() #fish red
ggplot(rear3_all,aes(x=rearlight,y=fish_orange,color=rearlight))+geom_boxplot() #fish orange
ggplot(rear3_all,aes(x=rearlight,y=fish_yellow,color=rearlight))+geom_boxplot() #fish yellow
ggplot(rear3_all,aes(x=rearlight,y=fish_magenta,color=rearlight))+geom_boxplot() #fish magneta
ggplot(rear3_all,aes(x=rearlight,y=fish_violet,color=rearlight))+geom_boxplot() #fish violet
ggplot(rear3_all,aes(x=rearlight,y=fish_blue,color=rearlight))+geom_boxplot() #fish blue
ggplot(rear3_all,aes(x=rearlight,y=fish_green,color=rearlight))+geom_boxplot() #fish green
ggplot(rear3_all,aes(x=rearlight,y=fish_black,color=rearlight))+geom_boxplot() #fish black
#most show little difference, maybe green?

hist(rear3_all$fish_black)
hist(rear3_all$fish_red) 
hist(rear3_all$fish_orange)
hist(rear3_all$fish_yellow)
hist(rear3_all$fish_green)
hist(rear3_all$fish_blue)
hist(rear3_all$fish_violet)
hist(rear3_all$fish_magenta)
#no colours are normal

hist(sqrt(rear3_all$fish_black))
hist(sqrt(rear3_all$fish_red)) 
hist(sqrt(rear3_all$fish_orange))
hist(sqrt(rear3_all$fish_yellow))
hist(sqrt(rear3_all$fish_green))
hist(sqrt(rear3_all$fish_blue))
hist(log(rear3_all$fish_violet)) #log better for violet
hist(sqrt(rear3_all$fish_magenta))


rear3_all$fish_black.sq <- sqrt(rear3_all$fish_black)
rear3_all$fish_red.sq <- sqrt(rear3_all$fish_red)
rear3_all$fish_orange.sq <- sqrt(rear3_all$fish_orange)
rear3_all$fish_yellow.sq <- sqrt(rear3_all$fish_yellow)
rear3_all$fish_green.sq <- sqrt(rear3_all$fish_green)
rear3_all$fish_blue.sq <- sqrt(rear3_all$fish_blue)
rear3_all$fish_violet.lg <- log(rear3_all$fish_violet)
rear3_all$fish_magenta.sq <- sqrt(rear3_all$fish_magenta)


hist(rear3_all$fish_black.sq)
hist(rear3_all$fish_red.sq) 
hist(rear3_all$fish_orange.sq)
hist(rear3_all$fish_yellow.sq)
hist(rear3_all$fish_green.sq)
hist(rear3_all$fish_blue.sq)
hist(rear3_all$fish_violet.lg) 
hist(rear3_all$fish_magenta.sq)
#all normal now


####do fish differ in green?####

m1 <- lmer(fish_green.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(m1)   
rand(m1) #only tag & momID needed

m1a <- lmer(fish_green.sq~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all)

AIC(m1,m1a)

plot(m1a) 
hist(resid(m1a))

drop1(m1a,test="Chisq")
m2<-update(m1a,.~.-rearlight:species)
drop1(m2,test="Chisq")
m3<-update(m2,.~.-species)
drop1(m3,test="Chisq") #rearlight (0.0004) & SL (0.063) trending

plot(allEffects(m3)) #smaller fish more green, deep fish more green

m4<-update(m3,.~.-SL)
m4a<-update(m3,.~.-rearlight)

m5<-update(m4,.~.-rearlight)
m5a<-update(m5,.~.+species)

KRmodcomp(m4,m5) #rearlight = 0.0016
KRmodcomp(m4a,m5) #SL = 0.22
KRmodcomp(m5a,m5) #species = 0.62

#mean green per rearlight
aggregate(rear3_all[, 47], list(rear3_all$rearlight), mean)

#posthoc testing using multcomp
rear3_all$inter <- interaction (rear3_all$rearlight,rear3_all$species)
m5a <- update(m5,.~.+inter)
library(multcomp)
posthoc<-glht(m5a, linfct=mcp(inter="Tukey"))
summary(posthoc)


####do fish differ in red?####

m10 <- lmer(fish_red.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(m10)
rand(m10) #position & dadID not needed

m10a <- lmer(fish_red.sq~rearlight*species+SL+(1|tag)+(1|tank)+(1|momID),data=rear3_all)

AIC(m10,m10a)

plot(m10a)
rand(m10a)
hist(resid(m10a))

drop1(m10a,test="Chisq")
m11<-update(m10a,.~.-rearlight:species)
drop1(m11,test="Chisq")
m12<-update(m11,.~.-rearlight)
drop1(m12,test="Chisq")
m13<-update(m12,.~.-SL)
drop1(m13,test="Chisq") #only species is sig (0.003)

plot(allEffects(m13))#P. nye with most red, hy next, P. pun lowest

m14<-update(m13,.~.-species)
KRmodcomp(m13,m14) #species = 0.013

m14a<-update(m14,.~.+rearlight)
KRmodcomp(m14a,m14) #rearlight = 0.78

m14b<-update(m14,.~.+SL)
KRmodcomp(m14b,m14) #SL = 0.77

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(m13, linfct=mcp(species="Tukey"))
summary(posthoc)
#P. nye & hyrbids no diff, but P & N, as well as P & H sig diff


####do fish differ in blue?####

m20 <- lmer(fish_blue.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(m20)   
rand(m20) #only tag & momID needed

m20a <- lmer(fish_blue.sq~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all)

AIC(m20,m20a)

plot(m20a) 
hist(resid(m20a))

drop1(m20a,test="Chisq")
m21<-update(m20a,.~.-rearlight:species)
drop1(m21,test="Chisq")
m22<-update(m21,.~.-SL)
drop1(m22,test="Chisq")
m23<-update(m22,.~.-rearlight)
drop1(m23,test="Chisq") #species trending (0.059)

plot(allEffects(m23))
#same colour pattern as red (P.nye have most, P. pun least)

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(m23, linfct=mcp(species="Tukey"))
summary(posthoc)
#only P & N differ significantly, P & H trending

m24<-update(m23,.~.-species)
KRmodcomp(m23,m24) #species = 0.107

m24a<-update(m24,.~.+rearlight)
KRmodcomp(m24a,m24) #rearlight = 0.23

m24b<-update(m24,.~.+SL)
KRmodcomp(m24b,m24) #SL = 0.85


####do fish differ in yellow?####

m30 <- lmer(fish_yellow.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(m30)
rand(m30) #only tag needed

m30a <- lmer(fish_yellow.sq~rearlight*species+SL+(1|tag),data=rear3_all)
plot(m30a)
rand(m30a)

AIC(m30,m30a)

drop1(m30a,test="Chisq")
m31<-update(m30a,.~.-rearlight:species)
drop1(m31,test="Chisq")
m32<-update(m31,.~.-rearlight)
drop1(m32,test="Chisq")
m33<-update(m32,.~.-SL)
drop1(m33,test="Chisq") #species sig (0.0001)

plot(allEffects(m33)) #P. pun highest in yellow

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(m33, linfct=mcp(species="Tukey"))
summary(posthoc)
#P differ significantly from N & H; N & H no diff

m34<-update(m33,.~.-species)
KRmodcomp(m33,m34) #species = 0.00019

m34a<-update(m34,.~.+rearlight)
KRmodcomp(m34a,m34) #rearlight = 0.41

m34b<-update(m34,.~.+SL)
KRmodcomp(m34b,m34) #SL = 0.11


####do fish differ in orange?####

m40 <- lmer(fish_orange.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(m40)  
rand(m40) #only tag needed

m40a <- lmer(fish_orange.sq~rearlight*species+SL+(1|tag),data=rear3_all)
plot(m40a)
rand(m40a)

AIC(m40,m40a)

drop1(m40a,test="Chisq")
m41<-update(m40a,.~.-rearlight:species)
drop1(m41,test="Chisq")
m42<-update(m41,.~.-rearlight)
drop1(m42,test="Chisq")
m43<-update(m42,.~.-species)
drop1(m43,test="Chisq")
m44<-update(m43,.~.-SL)
drop1(m44,test="Chisq")

KRmodcomp(m43,m44) #rearlight = 0.26

m44a<-update(m44,.~.+species)
KRmodcomp(m44a,m44) #species = 0.64

m44b<-update(m44,.~.+SL)
KRmodcomp(m44b,m44) #SL = 0.26

#NO differences in orange


####do fish differ in magenta?####

m50 <- lmer(fish_magenta.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(m50)
rand(m50) #only tag needed, maybe momID

m50a <- lmer(fish_magenta.sq~rearlight*species+SL+(1|tag),data=rear3_all)
plot(m50a)
             
AIC(m50,m50a)

drop1(m50a,test="Chisq") 
m51<-update(m50a,.~.-rearlight:species)
drop1(m51,test="Chisq")
m52<-update(m51,.~.-rearlight)
drop1(m52,test="Chisq") #species sig (0.00001) & SL sig (0.003) 
m53<-update(m52,.~.-SL)
drop1(m53,test="Chisq") #sig species effect

plot(allEffects(m53)) #N with very high magenta

m54<-update(m53,.~.-species)
KRmodcomp(m53,m54) #species < 0.0001

m54a<-update(m54,.~.+SL)
KRmodcomp(m54a,m54) #SL =0.302

m54b<-update(m54,.~.+rearlight)
KRmodcomp(m54b,m54) #rearlight =0.708

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(m53, linfct=mcp(species="Tukey"))
summary(posthoc)
#N sig different from both H & P; P & H diff trending


####do fish differ in violet?####

m60 <- lmer(fish_violet.lg~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(m60)
rand(m60) #position, momID not needed

m60a <- lmer(fish_violet.lg~rearlight*species+SL+(1|tag)+(1|tank)+(1|dadID),data=rear3_all)
plot(m60a)
rand(m60a) #tank & dadID not needed

m60b <- lmer(fish_violet.lg~rearlight*species+SL+(1|tag),data=rear3_all)

AIC(m60,m60b)

drop1(m60b,test="Chisq")
m61<-update(m60b,.~.-rearlight:species)
drop1(m61,test="Chisq")
m62<-update(m61,.~.-rearlight)
drop1(m62,test="Chisq") 
m63<-update(m62,.~.-SL)
drop1(m63,test="Chisq")#species sig

plot(allEffects(m63))
#P. nye most violet, P. pun the least

m64<-update(m63,.~.-species)
KRmodcomp(m63,m64) #species = 0.0011

m64a<-update(m64,.~.+SL)
KRmodcomp(m64a,m64) #SL = 0.62

m64b<-update(m64,.~.+rearlight)
KRmodcomp(m64b,m64) #rearlight = 0.55

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(m63, linfct=mcp(species="Tukey"))
summary(posthoc)
#N sig diff from H & P; P & H no difference

#mean violet per rearlight
aggregate(rear3_all[, 45], list(rear3_all$rearlight), mean)


####do fish differ in black?####

m70 <- lmer(fish_black.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(m70)
rand(m70) #tag & momID needed

m70a <- lmer(fish_black.sq~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all)
rand(m70a)

AIC(m70,m70a)

drop1(m70a,test="Chisq") 
m71<-update(m70a,.~.-rearlight:species)
drop1(m71,test="Chisq")
m72<-update(m71,.~.-species)
drop1(m72,test="Chisq") #rearlight trending
m73<-update(m72,.~.-rearlight)
drop1(m73,test="Chisq")
m74<-update(m73,.~.-species)
drop1(m74,test="Chisq")
m75<-update(m74,.~.-SL)
drop1(m75,test="Chisq")

plot(allEffects(m74)) #larger fish more black

KRmodcomp(m74,m75) #SL = 0.08

m75a<-update(m75,.~.+species)
KRmodcomp(m75a,m75) #species = 0.64

m75b<-update(m75a,.~.+rearlight)
KRmodcomp(m75b,m75) #rearlight = 0.50

#####combined fish colour figure####
#mean & sd per colour
#green
aggregate(rear3_all[, 47], list(rear3_all$rearlight), mean)
aggregate(rear3_all[, 47], list(rear3_all$rearlight), sd)

#orange
aggregate(rear3_all[, 43], list(rear3_all$rearlight), mean)
aggregate(rear3_all[, 43], list(rear3_all$rearlight), sd)

#black
aggregate(rear3_all[, 45], list(rear3_all$rearlight), mean)
aggregate(rear3_all[, 45], list(rear3_all$rearlight), sd)

#blue
aggregate(rear3_all[, 46], list(rear3_all$rearlight), mean)
aggregate(rear3_all[, 46], list(rear3_all$rearlight), sd)

#magenta, red, violet, yellow
aggregate(rear3_all[, 48:51], list(rear3_all$rearlight), mean)
aggregate(rear3_all[, 48:51], list(rear3_all$rearlight), sd)

limits <- aes(ymax = mean + se, ymin=mean - se)
all_colours$colour2 <- factor(all_colours$colour, c("Magenta","Violet", "Blue","Green","Yellow","Orange","Red","Black"))

plot(ggplot(all_colours, aes(x = colour2, y = mean, fill=rearlight)) +
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  theme(axis.text.x = element_text(size=12,face="bold"))+
  scale_y_continuous(expand = c(0, 0), limits = c(0, 25))+ 
  geom_bar(stat = "identity",position="dodge",width=0.7) +
  geom_errorbar(limits, position=position_dodge(width=0.7), width=0.25)+
  scale_fill_manual(values=c("orangered2","deepskyblue3"),
  guide = guide_legend(title = ""))+
  theme(legend.position=c(0.16,0.85),legend.background = element_rect(colour = 'white'),
  panel.spacing = unit(1,"lines"))+
  labs(x="",y="Mean colour score (%)")) 

#only green, per species & rearlight
aggregate(rear3_all[, 47], list(rear3_all$species,rear3_all$rearlight), mean)
aggregate(rear3_all[, 47], list(rear3_all$species,rear3_all$rearlight), sd)
table(rear3_all$species:rear3_all$rearlight) 

all_colours2$species <- factor(all_colours2$species, levels=c('n','h','p'))

plot(ggplot(all_colours2, aes(x = species, y = mean, fill=rearlight)) +
      theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
      theme(axis.text.x = element_text(size=12,face="bold"))+
      scale_y_continuous(expand = c(0, 0), limits = c(0, 12))+ 
      geom_bar(stat = "identity",position="dodge",width=0.7) +
      geom_errorbar(limits, position=position_dodge(width=0.7), width=0.25)+
      scale_fill_manual(values=c("orangered2","deepskyblue3"),
      guide = guide_legend(title = ""))+
      scale_x_discrete(name="", labels=c("P.nyererei","Hybrid","P.pundamila"))+
      theme(legend.position=c(0.76,0.85),legend.background = element_rect(colour = 'white'),
      panel.spacing = unit(1,"lines"))+
      labs(x="",y="Green colour score (%)"))



#####Same patterns with body colour?####
hist(rear3_all$body_black)
hist(rear3_all$body_red) 
hist(rear3_all$body_orange)
hist(rear3_all$body_yellow)
hist(rear3_all$body_green)
hist(rear3_all$body_blue)
hist(rear3_all$body_violet)
hist(rear3_all$body_magenta)
#no colours are normal

hist(sqrt(rear3_all$body_black))
hist(log(rear3_all$body_red)) #log better for red
hist(sqrt(rear3_all$body_orange))
hist(sqrt(rear3_all$body_yellow))
hist(sqrt(rear3_all$body_green))
hist(sqrt(rear3_all$body_blue))
hist(log(rear3_all$body_violet)) #log better for violet
hist(log(rear3_all$body_magenta)) #log better for magenta


rear3_all$body_black.sq <- sqrt(rear3_all$body_black)
rear3_all$body_red.lg <- log(rear3_all$body_red)
rear3_all$body_orange.sq <- sqrt(rear3_all$body_orange)
rear3_all$body_yellow.sq <- sqrt(rear3_all$body_yellow)
rear3_all$body_green.sq <- sqrt(rear3_all$body_green)
rear3_all$body_blue.sq <- sqrt(rear3_all$body_blue)
rear3_all$body_violet.lg <- log(rear3_all$body_violet)
rear3_all$body_magenta.lg <- log(rear3_all$body_magenta)


hist(rear3_all$body_black.sq)
hist(rear3_all$body_red.lg) 
hist(rear3_all$body_orange.sq)
hist(rear3_all$body_yellow.sq)
hist(rear3_all$body_green.sq)
hist(rear3_all$body_blue.sq)
hist(rear3_all$body_violet.lg) 
hist(rear3_all$body_magenta.lg)
#all normal now


####do bodies differ in green?####

mb1 <- lmer(body_green.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(mb1)   
rand(mb1) #tag & momID needed

mb1a <- lmer(body_green.sq~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all)

AIC(mb1,mb1a)
summary(m1)

plot(mb1a) 
hist(resid(mb1a))

drop1(mb1a,test="Chisq")
mb2<-update(mb1a,.~.-rearlight:species)
drop1(mb2,test="Chisq")
mb3<-update(mb2,.~.-species)
drop1(mb3,test="Chisq") #both rearlight (0.0006) & SL (0.031) are sig

plot(allEffects(mb3)) #smaller fish more green, deep fish more green

mb4<-update(mb3,.~.-SL)
mb4a<-update(mb3,.~.-rearlight)

mb5<-update(mb4,.~.-rearlight)
mb5a<-update(mb5,.~.+species)

KRmodcomp(mb4,mb5) #rearlight = 0.0025
KRmodcomp(mb4a,mb5) #SL = 0.18
KRmodcomp(mb5a,mb5) #species = 0.54


####do bodies differ in red?####

mb10 <- lmer(body_red.lg~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(mb10)
rand(mb10) #tag & dadID needed

mb10a <- lmer(body_red.lg~rearlight*species+SL+(1|tag)+(1|dadID),data=rear3_all)

AIC(mb10,mb10a)

plot(mb10a)
rand(mb10a)
hist(resid(mb10a))

drop1(mb10a,test="Chisq")
mb11<-update(mb10a,.~.-rearlight:species)
drop1(mb11,test="Chisq")
mb12<-update(mb11,.~.-SL)
drop1(mb12,test="Chisq")
mb13<-update(mb12,.~.-rearlight)
drop1(mb13,test="Chisq") #only species is sig (<0.0001)

plot(allEffects(mb13))#P. nye with most red, hy next, P. pun lowest

mb14<-update(mb13,.~.-species)
KRmodcomp(mb13,mb14) #species = 0.025

mb14a<-update(mb14,.~.+rearlight)
KRmodcomp(mb14a,mb14) #rearlight = 0.17

mb14b<-update(mb14,.~.+SL)
KRmodcomp(mb14b,mb14) #SL = 0.51

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(m13, linfct=mcp(species="Tukey"))
summary(posthoc)
#P. nye & hyrbids no diff, but P & N, as well as P & H sig diff


####do bodies differ in blue?####

mb20 <- lmer(body_blue.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(mb20)   
rand(mb20) #only tag needed, maybe momID

mb20a <- lmer(body_blue.sq~rearlight*species+SL+(1|tag),data=rear3_all)

AIC(mb20,mb20a)

plot(mb20a) 
hist(resid(mb20a))

drop1(mb20a,test="Chisq")
mb21<-update(mb20a,.~.-rearlight:species)
drop1(mb21,test="Chisq")
mb22<-update(mb21,.~.-SL)
drop1(mb22,test="Chisq")
mb23<-update(mb22,.~.-rearlight)
drop1(mb23,test="Chisq") #species sig (<0.0001)

plot(allEffects(mb23))
#same colour pattern as red (P.nye have most, P. pun least)

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(mb23, linfct=mcp(species="Tukey"))
summary(posthoc)
#only P & N differ significantly, P & H trending

mb24<-update(mb23,.~.-species)
KRmodcomp(mb23,mb24) #species < 0.0001

mb24a<-update(mb24,.~.+rearlight)
KRmodcomp(mb24a,mb24) #rearlight = 0.41

mb24b<-update(mb24,.~.+SL)
KRmodcomp(mb24b,mb24) #SL = 0.55


####do bodies differ in yellow?####

mb30 <- lmer(body_yellow.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(mb30)
rand(mb30) #only tag needed, maybe momID

mb30a <- lmer(body_yellow.sq~rearlight*species+SL+(1|tag),data=rear3_all)
plot(mb30a)
rand(mb30a)

AIC(mb30,mb30a)

drop1(mb30a,test="Chisq")
mb31<-update(mb30a,.~.-rearlight:species)
drop1(mb31,test="Chisq")
mb32<-update(mb31,.~.-rearlight)
drop1(mb32,test="Chisq") #species & SL sig

plot(allEffects(mb32)) #P. pun highest in yellow, smaller fish more yellow

mb33<-update(mb32,.~.-SL)
drop1(mb33,test="Chisq") 


#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(mb33, linfct=mcp(species="Tukey"))
summary(posthoc)
#P differ significantly from N & H; N & H no diff

mb34<-update(mb33,.~.-species)
KRmodcomp(mb33,mb34) #species = 0.001

mb34a<-update(mb34,.~.+rearlight)
KRmodcomp(mb34a,mb34) #rearlight = 0.38

mb34b<-update(mb34,.~.+SL)
KRmodcomp(mb34b,mb34) #SL = 0.09


####do bodies differ in orange?####

mb40 <- lmer(body_orange.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(mb40)  
rand(mb40) #only tag needed

mb40a <- lmer(body_orange.sq~rearlight*species+SL+(1|tag),data=rear3_all)
plot(mb40a)
rand(mb40a)

AIC(mb40,mb40a)

drop1(mb40a,test="Chisq")
mb41<-update(mb40a,.~.-rearlight:species)
drop1(mb41,test="Chisq")
mb42<-update(mb41,.~.-rearlight)
drop1(mb42,test="Chisq")
mb43<-update(mb42,.~.-species)
drop1(mb43,test="Chisq")
mb44<-update(mb43,.~.-SL)
drop1(mb44,test="Chisq")

KRmodcomp(mb43,mb44) #rearlight = 0.10

mb44a<-update(mb44,.~.+species)
KRmodcomp(mb44a,mb44) #species = 0.71

mb44b<-update(mb44,.~.+SL)
KRmodcomp(mb44b,mb44) #SL = 0.10

#NO differences in orange


####do bodies differ in magenta?####

mb50 <- lmer(body_magenta.lg~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(mb50)
rand(mb50) #only tag needed

mb50a <- lmer(body_magenta.lg~rearlight*species+SL+(1|tag),data=rear3_all)
plot(mb50a)

AIC(mb50,mb50a)

drop1(mb50a,test="Chisq") 
mb51<-update(mb50a,.~.-rearlight:species)
drop1(mb51,test="Chisq")
mb52<-update(mb51,.~.-SL)
drop1(mb52,test="Chisq") #species sig (0.00001) & rearlight sig (0.022) 
mb53<-update(mb52,.~.-rearlight)
drop1(mb53,test="Chisq") #sig species effect

plot(allEffects(mb52)) #N with very high magenta, less magenta in deep

mb54<-update(mb53,.~.-species)
KRmodcomp(mb53,mb54) #species < 0.0001

mb54a<-update(mb54,.~.+SL)
KRmodcomp(mb54a,mb54) #SL =0.55

mb54b<-update(mb54,.~.+rearlight)
KRmodcomp(mb54b,mb54) #rearlight =0.10

#posthoc testing using multcomp
library(multcomp)
posthoc<-glht(mb53, linfct=mcp(species="Tukey"))
summary(posthoc)
#N sig different from both H & P; P & H diff trending


####do body differ in violet?####

mb60 <- lmer(body_violet.lg~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(mb60)
rand(mb60) #tag needed, dadID as well

mb60a <- lmer(body_violet.lg~rearlight*species+SL+(1|tag)+(1|dadID),data=rear3_all)
plot(mb60a)
rand(mb60a) #tank not needed

AIC(mb60,mb60a)

drop1(mb60a,test="Chisq")
mb61<-update(mb60a,.~.-rearlight:species)
drop1(mb61,test="Chisq")
mb62<-update(mb61,.~.-species)
drop1(mb62,test="Chisq") 
mb63<-update(mb62,.~.-SL)
drop1(mb63,test="Chisq")
mb64<-update(mb63,.~.-rearlight)

KRmodcomp(mb63,mb64) #rearlight = 0.13

mb64a<-update(mb64,.~.+SL)
KRmodcomp(mb64a,mb64) #SL = 0.50

mb64b<-update(mb64,.~.+species)
KRmodcomp(mb64b,mb64) #species = 0.92

#NO differences in violet


####do bodies differ in black?####

mb70 <- lmer(body_black.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
plot(mb70)
rand(mb70) #tag & momID needed

mb70a <- lmer(body_black.sq~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all)
rand(mb70a)

AIC(mb70,mb70a)

drop1(mb70a,test="Chisq") 
mb71<-update(mb70a,.~.-rearlight:species)
drop1(mb71,test="Chisq")
mb72<-update(mb71,.~.-species)
drop1(mb72,test="Chisq") #rearlight trending (0.06)
mb73<-update(mb72,.~.-rearlight)
drop1(mb73,test="Chisq")
mb74<-update(mb73,.~.-SL)
drop1(mb74,test="Chisq")

plot(allEffects(mb73)) #larger fish more black

KRmodcomp(mb73,mb74) #SL = 0.11

mb74a<-update(mb74,.~.+species)
KRmodcomp(mb74a,mb74) #species = 0.62

mb74b<-update(mb74,.~.+rearlight)
KRmodcomp(mb74b,mb74) #rearlight = 0.15


#####what if colours are classified as long vs. short wavelength?####
rear3_all$long <- (rear3_all$fish_red + rear3_all$fish_orange + rear3_all$fish_yellow)
rear3_all$short <-(rear3_all$fish_blue + rear3_all$fish_green + rear3_all$fish_violet) 

rear3_all$ratio <- (rear3_all$short/rear3_all$long)

hist(rear3_all$short)
hist(rear3_all$long)
hist(rear3_all$ratio)

#transform both for normality
rear3_all$short.sq <- sqrt(rear3_all$short)
rear3_all$long.sq <- sqrt(rear3_all$long)

#long wavelengths
long1 <- lmer(long.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
rand(long1) #only tag

long1.1 <- lmer(long.sq~rearlight*species+SL+(1|tag),data=rear3_all)
AIC(long1,long1.1)
plot(long1.1)

drop1(long1.1,test="Chisq")
long2 <- update(long1.1,.~.-rearlight:species)
drop1(long2,test="Chisq")
long3 <- update(long2,.~.-rearlight)
drop1(long3,test="Chisq")
long4 <- update(long3,.~.-species)
drop1(long4,test="Chisq")
long5 <- update(long4,.~.-SL)
drop1(long5,test="Chisq")

plot(allEffects(long4))
#N have lowest long-wavelength total?
#P have highest - related to yellow most likely

KRmodcomp(long4,long5) #SL = 0.37

long5.1 <- update(long5,.~.+species)
KRmodcomp(long5.1,long5) #species = 0.60

long5.2 <- update(long5,.~.+rearlight)
KRmodcomp(long5.2,long5) #rearlight = 0.70

#No differences in long wavelengths


#short wavelengths
short1 <- lmer(short.sq~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
rand(short1) #only tag & momID

short1.1 <- lmer(short.sq~rearlight*species+SL+(1|tag)+(1|momID),data=rear3_all)
AIC(short1,short1.1)
plot(short1.1)

drop1(short1.1,test="Chisq")
short2 <- update(short1.1,.~.-rearlight:species)
drop1(short2,test="Chisq")
short3 <- update(short2,.~.-SL)
drop1(short3,test="Chisq")
short4 <- update(short3,.~.-species)
drop1(short4,test="Chisq")

plot(allEffects(short4))
#deep-reared fish express more short-wavelength

short5 <- update(short4,.~.-rearlight)

KRmodcomp(short4,short5) #rearlight = 0.0095

short5.1 <- update(short5,.~.+species)
KRmodcomp(short5.1,short5) #species = 0.22

short5.2 <- update(short5,.~.+SL)
KRmodcomp(short5.2,short5) #SL = 0.70


#proportion of long/short?

rear3_all$ratio <- (rear3_all$long.sq/rear3_all$short.sq)
hist(rear3_all$ratio)

rat1 <- lmer(ratio~rearlight*species+SL+(1|tag)+(1|position)+(1|tank)+(1|momID)+(1|dadID),data=rear3_all)
rand(rat1) #only tag 

rat1.1 <- lmer(ratio~rearlight*species+SL+(1|tag),data=rear3_all)
AIC(rat1,rat1.1)
plot(rat1.1)

drop1(rat1.1,test="Chisq")
rat2 <- update(rat1.1,.~.-rearlight:species)
drop1(rat2,test="Chisq")
rat3 <- update(rat2,.~.-SL)
drop1(rat3,test="Chisq")
rat4 <- update(rat3,.~.-rearlight)
drop1(rat4,test="Chisq")

plot(allEffects(rat4))
#N has highest proportion of short/long
#but no light effect

