#analysis of switched fish using pcs
#differences from mean for each individual

library(MASS)
library(lme4)
library(nlme)
library(ggplot2)
library(stats)
library(effects)
library(splines)
library(xlsx)
library(car)
library(lattice)
library(grid)
library(gridExtra)
library(pbkrtest)


#Whole fish
#to calculate PCs
pc <- prcomp(~fish_red + fish_orange + fish_yellow + fish_green + fish_blue + fish_magenta + fish_violet + fish_black, data=pc_all, scale.=TRUE)
# with standardized mean 

summary(pc)
plot(pc) 
plot(pc,type="lines")
biplot(pc, scale =0)# biplot; scale = 0 insures arrows reflect loadings
pc$rotation #Loading matrix

#to add PC's to exisiting data frame for analysis
str(pc)
pc_all.f<-cbind(pc_all,pc$x)

library(xlsx)
write.xlsx(pc_all.f, "/Users/dswright08/Desktop/Whole fish.xlsx")
write.xlsx(fit4$rotation, "/Users/dswright08/Desktop/fit4.xlsx")

#body
pc1 <- prcomp(~body_red + body_orange + body_yellow + body_green + body_blue + body_magenta + body_violet + body_black, data=pc_all, scale.=TRUE)
# with standardized mean 

summary(pc1)
plot(pc1) 
biplot(pc1, scale =0)# biplot; scale = 0 insures arrows reflect loadings
pc1$rotation #Loading matrix

#to add PC's to exisiting data frame for analysis
str(pc1)
pc_all.b<-cbind(pc_all,pc1$x)

library(xlsx)
write.xlsx(pc_all.b, "/Users/dswright08/Desktop/Body.xlsx")
write.xlsx(pc1$rotation, "/Users/dswright08/Desktop/pc1.xlsx")

#dorsal
pc2 <- prcomp(~dor_red + dor_orange + dor_yellow + dor_green + dor_blue + dor_magenta + dor_violet + dor_black, data=pc_all, scale.=TRUE)
# with standardized mean 

summary(pc2)
plot(pc2) 
biplot(pc2, scale =0)# biplot; scale = 0 insures arrows reflect loadings
pc2$rotation #Loading matrix

#to add PC's to exisiting data frame for analysis
str(pc2)
pc_all.d<-cbind(pc_all,pc2$x)

library(xlsx)
write.xlsx(pc_all.d, "/Users/dswright08/Desktop/Dorsal.xlsx")
write.xlsx(pc2$rotation, "/Users/dswright08/Desktop/pc2.xlsx")

#caudal
pc3 <- prcomp(~tail_red + tail_orange + tail_yellow + tail_green + tail_blue + tail_magenta + tail_violet + tail_black, data=pc_all, scale.=TRUE)
# with standardized mean 

summary(pc3)
plot(pc3) 
biplot(pc3, scale =0)# biplot; scale = 0 insures arrows reflect loadings
pc3$rotation #Loading matrix

#to add PC's to exisiting data frame for analysis
str(pc3)
pc_all.t<-cbind(pc_all,pc3$x)

library(xlsx)
write.xlsx(pc_all.t, "/Users/dswright08/Desktop/Caudal.xlsx")
write.xlsx(pc3$rotation, "/Users/dswright08/Desktop/pc3.xlsx")

#anal
pc4 <- prcomp(~anal_red + anal_orange + anal_yellow + anal_green + anal_blue + anal_magenta + anal_violet + anal_black, data=pc_all, scale.=TRUE)
# with standardized mean 

summary(pc4)
plot(pc4) 
biplot(pc4, scale =0)# biplot; scale = 0 insures arrows reflect loadings
pc4$rotation #Loading matrix

#to add PC's to exisiting data frame for analysis
str(pc4)
pc_all.a<-cbind(pc_all,pc4$x)

library(xlsx)
write.xlsx(pc_all.a, "/Users/dswright08/Desktop/Anal.xlsx")
write.xlsx(pc4$rotation, "/Users/dswright08/Desktop/pc4.xlsx")


#using data set with all pc's included
#differences from mean for each pc, each body part (calculated in excel)
#new dataset - switch_pc

str(switch_pc)

switch_pc$fam <- as.factor(switch_pc$fam)
switch_pc$momID <- as.factor(switch_pc$momID)
switch_pc$dadID <- as.factor(switch_pc$dadID)
switch_pc$tag <- as.factor(switch_pc$tag)
switch_pc$tank <- as.factor(switch_pc$tank)
switch_pc$position <- as.factor(switch_pc$position)
switch_pc$species <- as.factor(switch_pc$species)
switch_pc$treatment <- as.factor(switch_pc$treatment)


####First with Whole fish####
####PC1####
s1 <- lme(PC1.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
s1a <- lme(PC1.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(s1,s1a) #with tank is better

s1b <- lme(PC1.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|tank),control=lmeControl(opt = "optim"))
AIC(s1,s1b) #without position is better

s1c <- lme(PC1.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|tank),control=lmeControl(opt = "optim"))
AIC(s1b,s1c) #without dadID is better

s1d <- lme(PC1.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|tank),control=lmeControl(opt = "optim"))
AIC(s1c,s1d) #without momID is better

plot(ACF(s1d),alpha=0.05)

s1.1<-update(s1d,correlation=corAR1())
plot(ACF(s1.1),alpha=0.05)

anova(s1d,s1.1) #s1.1 is better

s1.2<-update(s1d,correlation=corARMA(q=2))
s1.3<-update(s1d,correlation=corARMA(q=3))
anova(s1.1,s1.2) #s1.1 is better
anova(s1.1,s1.3) #s1.1 is better

plot(s1.1)
qqnorm(s1.1,~resid(.)|tag)

s1.ml <-update(s1.1,method="ML")

drop1(s1.ml,test="Chisq")
s2 <- update(s1.ml,.~.-day:treatment:species)
drop1(s2, test="Chisq")
s3 <- update(s2,.~.-day:treatment)
drop1(s3, test="Chisq")
s4 <- update(s3,.~.-treatment:species)
drop1(s4, test="Chisq") #day:species is sig
s5 <- update(s4,.~.-treatment)
drop1(s5, test="Chisq") #day:species sig (0.008)

plot(allEffects(s5))

ggplot(switch_pc,aes(x=day,y=PC1.fish,colour=species,linetype=species))+
  geom_hline(yintercept=0,colour="gray88",size=1.5)+
  stat_smooth(se=F,size=0.9,show.legend = T,method=glm,fullrange = T)+
  scale_colour_manual(values = c("green","red","blue"))+
  scale_y_continuous(name="Fish PC1")+
  scale_x_continuous(name="Day")

drop1(s5, test="Chisq")
s6 <- update(s5,.~.-day:species)
drop1(s6, test="Chisq")
s7 <- update(s6,.~.-species)
drop1(s7, test="Chisq")
s8 <- update(s7,.~.-day)
drop1(s8, test="Chisq")

#convert back to REML prior to final determination
s8 <- update(s8,method="REML")
s8.1 <- update(s8,.~.+treatment)
anova(s8.1,test="Chisq") #treatment = 0.45
summary(s8.1)

s5a <- update(s5,method="REML")
anova(s5a,test="Chisq") #day:species = 0.009

s7a <- update(s7,method="REML")
summary(s7a)

species_f2 <- c(n = "P. nyererei",h="Hybrid", p = "P. pundamilia")

ggplot(switch_pc_fig,aes(x=photo,y=PC1.fish,colour = treatment))+
  geom_hline(yintercept=0,colour="gray61",size=0.5)+
  facet_grid(~species_f, labeller = labeller(.default = capitalize,species_f=species_f2))+
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  coord_cartesian(ylim=c(-5, 5))+
  stat_smooth(aes(fill = treatment,linetype=treatment),se=F,size=1,show.legend = F,method="glm",position = position_dodge(4.5))+
  stat_summary(fun.y = mean, geom = "point",size = 2.5,position = position_dodge(4.5)) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=0.95,position = position_dodge(4.5))+
  scale_colour_manual(name="",values = c("orangered2","lightpink2","lightblue3","deepskyblue3"))+
  scale_y_continuous(name="PC1")+
  scale_x_continuous(name="",breaks=c(0,11),labels=c("",""))+
  theme(legend.position='top',legend.background = element_rect(colour = 'white'),
  plot.margin=unit(c(0.2,0.2,0.2,0.2), "cm"),panel.spacing = unit(1.3,"lines"))


####PC2####
s10 <- lme(PC2.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
s10a <- lme(PC2.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(s10,s10a) #without tank is better

s10b <- lme(PC2.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID),control=lmeControl(opt = "optim"))
AIC(s10a,s10b) #with position is better

s10c <- lme(PC2.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|position),control=lmeControl(opt = "optim"))
AIC(s10a,s10c) #without dadID is better

s10d <- lme(PC2.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|position),control=lmeControl(opt = "optim"))
AIC(s10c,s10d) #without momID is better

plot(ACF(s10d),alpha=0.05)

s10.1<-update(s10d,correlation=corAR1())
plot(ACF(s10.1),alpha=0.05)

anova(s10d,s10.1) #s10.1 is better

s10.2<-update(s10d,correlation=corARMA(q=2))
s10.3<-update(s10d,correlation=corARMA(q=3))
s10.4<-update(s10d,correlation=corARMA(q=4))
anova(s10.1,s10.2) 
anova(s10.1,s10.3)
anova(s10.1,s10.4) #s10.4 is the best

plot(s10.4)
qqnorm(s10.4,~resid(.)|tag)

s10.ml <-update(s10.4,method="ML")

drop1(s10.ml,test="Chisq")
s12 <- update(s10.ml,.~.-day:treatment:species)
drop1(s12, test="Chisq")
s13 <- update(s12,.~.-day:species)
drop1(s13, test="Chisq")
s14 <- update(s13,.~.-day:treatment)
drop1(s14, test="Chisq") #treatment:species is sig
s15 <- update(s14,.~.-day)
drop1(s15, test="Chisq") #treatment:species (0.012)

plot(allEffects(s15))

ggplot(switch_pc,aes(x=treatment,y=PC2.fish,colour=species))+geom_hline(yintercept=0,colour="gray61",size=0.5)+
  stat_smooth(data=switch_pc,aes(treatment,PC2.fish,colour=species,group=species),se=FALSE,size=0.8,
  show.legend = F)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("forestgreen","red2","mediumblue"))+
  scale_y_continuous(name="Fish PC2")+
  scale_x_discrete(name="Treatment")

drop1(s15, test="Chisq")
s16 <- update(s15,.~.-treatment:species)
drop1(s16, test="Chisq")
s17 <- update(s16,.~.-species)
drop1(s17, test="Chisq")
s18 <- update(s17,.~.-treatment)

#convert back to REML prior to final determination
s18 <- update(s18,method="REML")
s18.1 <- update(s18,.~.+day)
anova(s18.1,test="Chisq") #day=0.54
summary(s18.1)

s15a <- update(s15,method="REML")
anova(s15a,test="Chisq") #treatment:species=0.04
anova(s15,test="Chisq") #lower p value if fit with ML

s17a <- update(s17,method="REML")
anova(s17a,test="Chisq") #treatment = 0.08

s18.2 <- update(s18,.~.+treatment)

#posthoc testing using multcomp
switch_pc$inter <- interaction (switch_pc$treatment,switch_pc$species)
s18.3 <- update(s18,.~.+inter)
library(multcomp)
posthoc<-glht(s18.3, linfct=mcp(inter="Tukey"))
summary(posthoc)


ggplot(switch_pc_fig,aes(x=photo,y=PC2.fish,colour = treatment))+
  geom_hline(yintercept=0,colour="gray61",size=0.5)+
  facet_grid(~species_f, labeller = labeller(.default = capitalize,species_f=species_f2))+
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  coord_cartesian(ylim=c(-5, 5))+
  stat_smooth(aes(fill = treatment,linetype=treatment),se=F,size=1,show.legend = F,method="glm",position = position_dodge(4.5))+
  stat_summary(fun.y = mean, geom = "point",size = 2.5,position = position_dodge(4.5)) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=0.95,position = position_dodge(4.5))+
  scale_colour_manual(name="",values = c("orangered2","lightpink2","lightblue3","deepskyblue3"))+
  scale_y_continuous(name="PC2")+
  scale_x_continuous(name="",breaks=c(0,11),labels=c("",""))+
  theme(legend.position='top',legend.background = element_rect(colour = 'white'),
  plot.margin=unit(c(0.2,0.2,0.2,0.2), "cm"),panel.spacing = unit(1.3,"lines"))


####PC3####
s20 <- lme(PC3.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
s20a <- lme(PC3.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(s20,s20a) #with tank is better

s20b <- lme(PC3.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|tank),control=lmeControl(opt = "optim"))
AIC(s20a,s20b) #without position is better

s20c <- lme(PC3.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|tank),control=lmeControl(opt = "optim"))
AIC(s20b,s20c) #without momID & dadID is better

plot(ACF(s20c),alpha=0.05)

s20.1<-update(s20c,correlation=corAR1())
plot(ACF(s20.1),alpha=0.05)

anova(s20c,s20.1) #s20.1 better

s20.2<-update(s20c,correlation=corARMA(q=2))
s20.3<-update(s20c,correlation=corARMA(q=3))
s20.4<-update(s20c,correlation=corARMA(q=6))
anova(s20.1,s20.2) 
anova(s20.1,s20.3)
anova(s20.1,s20.4) #at lag 6 is the best fit

plot(s20.4)
qqnorm(s20.4,~resid(.)|tag)

s20.ml <-update(s20.4,method="ML")

drop1(s20.ml,test="Chisq") #sig three way interaction (0.013)
plot(allEffects(s20.ml))

ggplot(switch_pc_fig,aes(x=photo,y=PC3.fish,colour = species_f))+
  geom_hline(yintercept=0,colour="gray61",size=0.5)+
  facet_grid(~treatment)+
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  coord_cartesian(ylim=c(-5.5, 5.5))+
  stat_smooth(aes(fill = species_f),se=F,size=1,show.legend = T,fullrange=T,method="glm",position = position_dodge(4.5))+
  stat_summary(fun.y = mean, geom = "point",size = 2.5,position = position_dodge(4.5)) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=0.95,position = position_dodge(4.5))+
  scale_colour_manual(values = c("red2","forestgreen","mediumblue"))+
  scale_y_continuous(name="Fish PC3")+
  scale_x_continuous(name="Day",breaks=c(0,11),labels=c("0","100"))+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
  plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1.3,"lines"))
  
ggplot(switch_pc_fig,aes(x=photo,y=PC3.fish,colour = treatment))+
  geom_hline(yintercept=0,colour="gray61",size=0.5)+
  facet_grid(~species_f, labeller = labeller(.default = capitalize,species_f=species_f2))+
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  coord_cartesian(ylim=c(-5, 5))+
  stat_smooth(aes(fill = treatment,linetype=treatment),se=F,size=1,show.legend = F,method="glm",position = position_dodge(4.5))+
  stat_summary(fun.y = mean, geom = "point",size = 2.5,position = position_dodge(4.5)) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=0.95,position = position_dodge(4.5))+
  scale_colour_manual(name="",values = c("orangered2","lightpink2","lightblue3","deepskyblue3"))+
  scale_y_continuous(name="PC3")+
  scale_x_continuous(name="",breaks=c(0,11),labels=c("",""))+
  theme(legend.position='top',legend.background = element_rect(colour = 'white'),
  plot.margin=unit(c(0.2,0.2,0.2,0.2), "cm"),panel.spacing = unit(1.3,"lines"))

s22 <- update(s20.ml,.~.-day:treatment:species)
drop1(s22, test="Chisq")
s23 <- update(s22,.~.-day:treatment)
drop1(s23, test="Chisq")
s24 <- update(s23,.~.-day:species)
drop1(s24, test="Chisq") 
s25 <- update(s24,.~.-treatment)

drop1(s25, test="Chisq")
s26 <- update(s25,.~.-species:treatment)
drop1(s26, test="Chisq")
s27 <- update(s26,.~.-species)
drop1(s27, test="Chisq")

plot(allEffects(s27))

#only an effect of day (increases with time/growth)

#convert back to REML prior to final determination
s27a <- update(s27,method="REML")
anova(s27a,test="Chisq") #day <0.0001
summary(s27a)

s20.mla <- update(s20.ml,method="REML")
anova(s20.mla,test="Chisq") #day:treatment:species = 0.0317
anova(s20.ml,test="Chisq")


####PC4####
s30 <- lme(PC4.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
s30a <- lme(PC4.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(s30,s30a) #with tank is better

s30b <- lme(PC4.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|tank),control=lmeControl(opt = "optim"))
AIC(s30,s30b) #without position is better

s30c <- lme(PC4.fish~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|tank),control=lmeControl(opt = "optim"))
AIC(s30b,s30c) #without momID & dadID is better

s30d <- lme(PC4.fish~day*treatment*species, data=switch_pc, random=list(~day|tag),control=lmeControl(opt = "optim"))
AIC(s30c,s30d) #with tank still best

plot(ACF(s30c),alpha=0.05)

s30.1<-update(s30c,correlation=corAR1())
plot(ACF(s30.1),alpha=0.05)

anova(s30c,s30.1) #s30c better

s30.2<-update(s30c,correlation=corARMA(q=2))
s30.3<-update(s30c,correlation=corARMA(q=3))
s30.4<-update(s30c,correlation=corARMA(q=4))
anova(s30c,s30.2) 
anova(s30c,s30.3)
anova(s30c,s30.4) #at lag 4 is the best fit

plot(s30.4)
qqnorm(s30.4,~resid(.)|tag)

s30.ml <-update(s30.4,method="ML")

drop1(s30.ml,test="Chisq") #sig three way interaction
plot(allEffects(s30.ml))

ggplot(switch_pc_fig,aes(x=photo,y=PC4.fish,colour = species_f))+
  geom_hline(yintercept=0,colour="gray61",size=0.5)+
  facet_grid(~treatment)+
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  coord_cartesian(ylim=c(-5.5, 5.5))+
  stat_smooth(aes(fill = species_f),se=F,size=1,show.legend = T,fullrange=T,method="glm",position = position_dodge(4.5))+
  stat_summary(fun.y = mean, geom = "point",size = 2.5,position = position_dodge(4.5)) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=0.95,position = position_dodge(4.5))+
  scale_colour_manual(values = c("red2","forestgreen","mediumblue"))+
  scale_y_continuous(name="Fish PC4")+
  scale_x_continuous(name="Day",breaks=c(0,11),labels=c("0","100"))+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
        plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1.3,"lines"))

ggplot(switch_pc_fig,aes(x=photo,y=PC4.fish,colour = treatment))+
  geom_hline(yintercept=0,colour="gray61",size=0.5)+
  facet_grid(~species_f, labeller = labeller(.default = capitalize,species_f=species_f2))+
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  coord_cartesian(ylim=c(-5, 5))+
  stat_smooth(aes(fill = treatment,linetype=treatment),se=F,size=1,show.legend = F,method="glm",position = position_dodge(4.5))+
  stat_summary(fun.y = mean, geom = "point",size = 2.5,position = position_dodge(4.5)) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=0.95,position = position_dodge(4.5))+
  scale_colour_manual(name="",values = c("orangered2","lightpink2","lightblue3","deepskyblue3"))+
  scale_y_continuous(name="PC4")+
  scale_x_continuous(name="",breaks=c(0,11),labels=c("0","100"))+
  theme(legend.position='top',legend.background = element_rect(colour = 'white'),
  plot.margin=unit(c(0.2,0.2,0.2,0.2), "cm"),panel.spacing = unit(1.3,"lines"))  

s32 <- update(s30.ml,.~.-day:treatment:species)
drop1(s32, test="Chisq")
s33 <- update(s32,.~.-day:species)
drop1(s33, test="Chisq")
s34 <- update(s33,.~.-treatment:species)
drop1(s34, test="Chisq") 
s35 <- update(s34,.~.-day:treatment)
drop1(s35, test="Chisq")
s36 <- update(s35,.~.-day)
drop1(s36, test="Chisq")
s37 <- update(s36,.~.-species)
drop1(s37, test="Chisq")
s38 <- update(s37,.~.-treatment)
drop1(s38, test="Chisq")

#With REML instead of ML
anova(s30.4,test="Chisq") #day:treatment:species = 0.055


#convert back to REML prior to final determination
s38 <- update(s8,method="REML")
s38.1 <- update(s38,.~.+treatment)
anova(s38.1,test="Chisq") 
summary(s8.1)

s38.2 <- update(s38,.~.+day)
summary(s38.2)


####Now with Body colour####
####PC1####
b1 <- lme(PC1.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
b1a <- lme(PC1.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(b1,b1a) #with tank is better

b1b <- lme(PC1.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|tank),control=lmeControl(opt = "optim"))
AIC(b1,b1b) #without position is better

b1c <- lme(PC1.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|tank),control=lmeControl(opt = "optim"))
AIC(b1b,b1c) #without momID & dadID is better

b1d <- lme(PC1.body~day*treatment*species, data=switch_pc, random=list(~day|tag,~1|momID, ~1|tank),control=lmeControl(opt = "optim"))
AIC(b1c,b1d) #without momID is better

plot(ACF(b1c),alpha=0.05)

b1.1<-update(b1c,correlation=corAR1())
plot(ACF(b1.1),alpha=0.05)

anova(b1c,b1.1) #b1.1 is better

b1.2<-update(b1c,correlation=corARMA(q=2))
b1.3<-update(b1c,correlation=corARMA(q=3))
anova(b1.1,b1.2) #b1.1 is better
anova(b1.1,b1.3) #b1.1 is better

plot(b1.1)
qqnorm(b1.1,~resid(.)|tag)

b1.ml <-update(b1.1,method="ML")

drop1(b1.ml,test="Chisq")
b2 <- update(b1.ml,.~.-day:treatment:species)
drop1(b2, test="Chisq")
b3 <- update(b2,.~.-day:treatment)
drop1(b3, test="Chisq")
b4 <- update(b3,.~.-treatment:species)
drop1(b4, test="Chisq") #day:species is sig
b5 <- update(b4,.~.-treatment)
drop1(b5, test="Chisq") #day:species sig (0.008)

plot(allEffects(b5))

ggplot(switch_pc,aes(x=day,y=PC1.body,colour=species,linetype=species))+
  geom_hline(yintercept=0,colour="gray88",size=1.5)+
  stat_smooth(se=F,size=0.9,show.legend = T,method=glm,fullrange = T)+
  scale_colour_manual(values = c("green","red","blue"))+
  scale_y_continuous(name="Body PC1")+
  scale_x_continuous(name="Day")

ggplot(switch_pc,aes(x=treatment,y=PC1.body,colour=species))+geom_hline(yintercept=0,colour="gray61",size=0.5)+
  stat_smooth(data=switch_pc,aes(treatment,PC1.body,colour=species,group=species),se=FALSE,size=0.8,
  show.legend = F)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("forestgreen","red2","mediumblue"))+
  scale_y_continuous(name="Body PC1")+
  scale_x_discrete(name="Treatment")

drop1(b5, test="Chisq")
b6 <- update(b5,.~.-day:species)
drop1(b6, test="Chisq")
b7 <- update(b6,.~.-species)
drop1(b7, test="Chisq")
b8 <- update(b7,.~.-day)
drop1(b8, test="Chisq")

#convert back to REML prior to final determination
b8 <- update(b8,method="REML")
b8.1 <- update(b8,.~.+treatment)
anova(b8.1,test="Chisq") #treatment = 0.27

b8.2 <- update(b8,.~.+day)
anova(b8.2,test="Chisq") 
summary(b8.2)

anova(b3,test="Chisq")
#day:species = 0.0004
#treatment:species = 0.0681

#posthoc testing using multcomp
switch_pc$inter <- interaction (switch_pc$treatment,switch_pc$species)
b8.3 <- update(b8,.~.+inter)
library(multcomp)
posthoc<-glht(b8.3, linfct=mcp(inter="Tukey"))
summary(posthoc)

####PC2####
b10 <- lme(PC2.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
b10a <- lme(PC2.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(b10,b10a) #without tank is better

b10b <- lme(PC2.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID),control=lmeControl(opt = "optim"))
AIC(b10a,b10b) #with position is better

b10c <- lme(PC2.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|position),control=lmeControl(opt = "optim"))
AIC(b10b,b10c) #without parental ID is better

plot(ACF(b10c),alpha=0.05)

b10.1<-update(b10c,correlation=corAR1())
plot(ACF(b10.1),alpha=0.05)

anova(b10c,b10.1) #b10.1 is better

b10.2<-update(b10c,correlation=corARMA(q=2))
b10.3<-update(b10c,correlation=corARMA(q=3))
b10.4<-update(b10c,correlation=corARMA(q=4))
anova(b10.1,b10.2) 
anova(b10.1,b10.3) #lag 3 seems best
anova(b10.1,b10.4) 

plot(b10.3)
qqnorm(b10.3,~resid(.)|tag)

b10.ml <-update(b10.3,method="ML")

drop1(b10.ml,test="Chisq")
b12 <- update(b10.ml,.~.-day:treatment:species)
drop1(b12, test="Chisq")
b13 <- update(b12,.~.-day:treatment)
drop1(b13, test="Chisq")
b14 <- update(b13,.~.-day:species)
drop1(b14, test="Chisq") 
b15 <- update(b14,.~.-treatment:species)
drop1(b15, test="Chisq") 
b16 <- update(b15,.~.-species)
drop1(b16, test="Chisq")
b17 <- update(b16,.~.-day)
drop1(b17, test="Chisq")
b18 <- update(b17,.~.-treatment)

#convert back to REML prior to final determination
b17a <- update(b17,method="REML")
anova(b17a,test="Chisq") #treatment = 0.146

b18 <- update(b18,method="REML")
b18.1 <- update(b18,.~.+day)
anova(b18.1,test="Chisq") #day = 0.57
summary(b18.1)

b18.2 <- update(b18,.~.+species)
anova(b18.2,test="Chisq") #species = 0.77


####PC3####
b20 <- lme(PC3.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
b20a <- lme(PC3.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(b20,b20a) #with tank is better

b20b <- lme(PC3.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|tank),control=lmeControl(opt = "optim"))
AIC(b20,b20b) #without position is better

b20c <- lme(PC3.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|tank),control=lmeControl(opt = "optim"))
AIC(b20b,b20c) #without parentID is better

plot(ACF(b20c),alpha=0.05)

b20.1<-update(b20c,correlation=corAR1())
plot(ACF(b20.1),alpha=0.05)

anova(b20c,b20.1) #b20.1 better

b20.2<-update(b20c,correlation=corARMA(q=2))
b20.3<-update(b20c,correlation=corARMA(q=3))
b20.4<-update(b20c,correlation=corARMA(q=4))
anova(b20.1,b20.2) 
anova(b20.1,b20.3)
anova(b20.1,b20.4) #at lag 4 is the best fit

plot(b20.4)
qqnorm(b20.4,~resid(.)|tag)

b20.ml <-update(b20.4,method="ML")

drop1(b20.ml,test="Chisq") #sig three way interaction
b22 <- update(b20.ml,.~.-day:treatment:species)
drop1(b22, test="Chisq")
b23 <- update(b22,.~.-day:species)
drop1(b23, test="Chisq")
b24 <- update(b23,.~.-day:treatment)
drop1(b24, test="Chisq") 
b25 <- update(b24,.~.-treatment:species)
drop1(b25, test="Chisq")
b26 <- update(b25,.~.-species)
drop1(b26, test="Chisq") #treatment trending, day sig
b27 <- update(b26,.~.-treatment)
drop1(b27, test="Chisq")
b28 <- update(b27,.~.-day)
drop1(b28, test="Chisq")

plot(allEffects(b26)) #SS fish get less green/blue with time

#convert back to REML prior to final determination
b27a <- update(b27,method="REML")
anova(b27a,test="Chisq") #day=0.006
summary(b27a)

b28 <- update(b28,method="REML")
b28.1 <- update(b28,.~.+treatment)
anova(b28.1, test="Chisq") #treatment=0.105

b28.2 <- update(b28,.~.+species)
anova(b28.2, test="Chisq") #species=0.33


####PC4####
b30 <- lme(PC4.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
b30a <- lme(PC4.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(b30,b30a) #with tank is better

b30b <- lme(PC4.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|tank),control=lmeControl(opt = "optim"))
AIC(b30,b30b) #without position is better

b30c <- lme(PC4.body~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|tank),control=lmeControl(opt = "optim"))
AIC(b30b,b30c) #without parent ID is better

plot(ACF(b30c),alpha=0.05)

b30.1<-update(b30c,correlation=corAR1())
plot(ACF(b30.1),alpha=0.05)

anova(b30c,b30.1) #b30.1 better

b30.2<-update(b30c,correlation=corARMA(q=2))
b30.3<-update(b30c,correlation=corARMA(q=3))
b30.4<-update(b30c,correlation=corARMA(q=4))
anova(b30.1,b30.2) 
anova(b30.1,b30.3)
anova(b30.1,b30.4) #at lag 4 is the best fit

plot(b30.4)
qqnorm(b30.4,~resid(.)|tag)

b30.ml <-update(b30.4,method="ML")

drop1(b30.ml,test="Chisq") #highly sig three way interaction
plot(allEffects(b30.ml))

#to change order of species in figure
switch_pc$species_f <- factor(switch_pc$species, levels=c('n','h','p'))

ggplot(switch_pc_fig,aes(x=photo,y=PC4.body,colour = species_f))+
  geom_hline(yintercept=0,colour="gray61",size=0.5)+
  facet_grid(~treatment)+
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  coord_cartesian(ylim=c(-5.5, 5.5))+
  stat_smooth(aes(fill = species_f),se=F,size=1,show.legend = T,fullrange=T,method="glm",position = position_dodge(4.5))+
  stat_summary(fun.y = mean, geom = "point",size = 2.5,position = position_dodge(4.5)) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=0.95,position = position_dodge(4.5))+
  scale_colour_manual(values = c("red2","forestgreen","mediumblue"))+
  scale_y_continuous(name="Body PC4")+
  scale_x_continuous(name="Day",breaks=c(0,11),labels=c("0","100"))+
  theme(legend.position='none',legend.background = element_rect(colour = 'black'),
        plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1.3,"lines"))

ggplot(switch_pc_fig,aes(x=photo,y=PC4.body,colour = treatment))+
  geom_hline(yintercept=0,colour="gray61",size=0.5)+
  facet_grid(~species)+
  theme(strip.text.x = element_text(size=12,face="bold"),strip.background = element_rect(colour="white",fill="white"))+
  coord_cartesian(ylim=c(-5, 5))+
  stat_smooth(aes(fill = treatment,linetype=treatment),se=F,size=1,show.legend = T,fullrange=T,method="glm",position = position_dodge(4.5))+
  stat_summary(fun.y = mean, geom = "point",size = 2.5,position = position_dodge(4.5)) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=0.95,position = position_dodge(4.5))+
  scale_colour_manual(values = c("orangered2","lightcoral","lightblue3","deepskyblue3"))+
  scale_y_continuous(name="Body PC4")+
  scale_x_continuous(name="Day",breaks=c(0,11),labels=c("0","100"))+
  theme(legend.position=c(1,1),legend.background = element_rect(colour = 'black'),
        plot.margin=unit(c(1,1,1,1), "cm"),panel.spacing = unit(1.3,"lines"))

b32 <- update(b30.ml,.~.-day:treatment:species)
drop1(b32, test="Chisq")
b33 <- update(b32,.~.-day:treatment)
drop1(b33, test="Chisq")
b34 <- update(b33,.~.-day:species)
drop1(b34, test="Chisq") #day sig, treatment:species sig

plot(allEffects(b34))

ggplot(switch_pc,aes(x=treatment,y=PC4.body,colour=species))+geom_hline(yintercept=0,colour="gray88",size=1)+
  stat_smooth(data=switch_pc,aes(treatment,PC4.body,colour=species,group=species),se=FALSE,size=0.8,
  show.legend = T)+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("green","red","blue"))+
  scale_y_continuous(name="PC4")+
  scale_x_discrete(name="Treatment")

drop1(b34, test="Chisq") #day sig, treatment:species sig

#convert back to REML prior to final determination
b30.mla <- update(b30.ml,method="REML")
anova(b30.mla,test="Chisq")

b34a <- update(b34,method="REML")
anova(b34,test="Chisq")

b35 <- update(b34,.~.-treatment:species)
drop1(b35,test="Chisq")
b36 <- update(b35,.~.-species)
b37 <- update(b36,.~.-treatment)
drop1(b37,test="Chisq")

b37a <- update(b37,method="REML")
anova(b37a,test="Chisq")
summary(b37a)

####Now with Dorsal colour####
####PC1####
d1 <- lme(PC1.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
d1a <- lme(PC1.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(d1,d1a) #without tank is better

d1b <- lme(PC1.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(d1a,d1b) #with position is better

d1c <- lme(PC1.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|position),control=lmeControl(opt = "optim"))
AIC(d1a,d1c) #without family is better

plot(ACF(d1c),alpha=0.05)

d1.1<-update(d1c,correlation=corAR1())
plot(ACF(d1.1),alpha=0.05)

anova(d1c,d1.1) #d1.1 is better

d1.2<-update(d1c,correlation=corARMA(q=2))
d1.3<-update(d1c,correlation=corARMA(q=3))
d1.4<-update(d1c,correlation=corARMA(q=4))
anova(d1.1,d1.2) #d1.1 is better
anova(d1.1,d1.3) #d1.1 is better
anova(d1.1,d1.4) #d1.1 is better

plot(d1.1)
qqnorm(d1.1,~resid(.)|tag)

d1.ml <-update(d1.1,method="ML")

drop1(d1.ml,test="Chisq")
d2 <- update(d1.ml,.~.-day:treatment:species)
drop1(d2, test="Chisq")
d3 <- update(d2,.~.-day:treatment)
drop1(d3, test="Chisq")
d4 <- update(d3,.~.-day:species)
drop1(d4, test="Chisq") 
d5 <- update(d4,.~.-treatment:species)
drop1(d5, test="Chisq") 
d6 <- update(d5,.~.-treatment)
drop1(d6, test="Chisq") #day highly sigh, species sig

plot(allEffects(d6))

d7 <- update(d6,.~.-species)
drop1(d7, test="Chisq")
d8 <- update(d7,.~.-day)
drop1(d8, test="Chisq")

#convert back to REML prior to final determination
d7a <- update(d7,method="REML")
anova(d7a,test="Chisq") #day=0.0002
summary(d7a)

d8 <- update(d8,method="REML")
d8.1 <- update(d8,.~.+treatment)
anova(d8.1,test="Chisq") #treatment = 0.74

d8.2 <- update(d8,.~.+species)
anova(d8.2,test="Chisq") #species=0.022


####PC2####
d10 <- lme(PC2.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
d10a <- lme(PC2.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(d10,d10a) #without tank is better

d10b <- lme(PC2.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(d10a,d10b) #with position is better

d10c <- lme(PC2.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|position),control=lmeControl(opt = "optim"))
AIC(d10b,d10c) #without family is better

plot(ACF(d10c),alpha=0.05)

d10.1<-update(d10c,correlation=corAR1())
plot(ACF(d10.1),alpha=0.05)

anova(d10c,d10.1) #d10.1 is better

d10.2<-update(d10c,correlation=corARMA(q=2))
d10.3<-update(d10c,correlation=corARMA(q=3))
d10.4<-update(d10c,correlation=corARMA(q=4))
anova(d10.1,d10.2) 
anova(d10.1,d10.3) 
anova(d10.1,d10.4) #d10.1 best

plot(d10.1)
qqnorm(d10.1,~resid(.)|tag)

d10.ml <-update(d10.1,method="ML")

drop1(d10.ml,test="Chisq")
d12 <- update(d10.ml,.~.-day:treatment:species)
drop1(d12, test="Chisq")
d13 <- update(d12,.~.-day:treatment)
drop1(d13, test="Chisq")
d14 <- update(d13,.~.-treatment:species)
drop1(d14, test="Chisq") 
d15 <- update(d14,.~.-day:species)
drop1(d15, test="Chisq") 
d16 <- update(d15,.~.-treatment)
drop1(d16, test="Chisq")
d17 <- update(d16,.~.-species)
drop1(d17, test="Chisq")
d18 <- update(d17,.~.-day)

#convert back to REML prior to final determination
d17a <- update(d17,method="REML")
anova(d17a,test="Chisq") #day<0.001
summary(d17a)
plot(allEffects(d17a))

d18 <- update(d18,method="REML")
d18.1 <- update(d18,.~.+treatment)
anova(d18.1,test="Chisq") #treatment = 0.83

d18.2 <- update(d18,.~.+species)
anova(d18.2,test="Chisq") #species = 0.82


####PC3####
d20 <- lme(PC3.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
d20a <- lme(PC3.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(d20,d20a) #without tank is better

d20b <- lme(PC3.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(d20a,d20b) #with position is better

d20c <- lme(PC3.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|position),control=lmeControl(opt = "optim"))
AIC(d20a,d20c) #without family is better

plot(ACF(d20c),alpha=0.05)

d20.1<-update(d20c,correlation=corAR1())
plot(ACF(d20.1),alpha=0.05)

anova(d20c,d20.1) #b20.1 better

d20.2<-update(d20c,correlation=corARMA(q=2))
d20.3<-update(d20c,correlation=corARMA(q=3))
d20.4<-update(d20c,correlation=corARMA(q=4))
anova(d20.1,d20.2) 
anova(d20.1,d20.3)
anova(d20.1,d20.4) #d20.1 best

plot(d20.1)
qqnorm(d20.1,~resid(.)|tag)

d20.ml <-update(d20.1,method="ML")

drop1(d20.ml,test="Chisq") 
d22 <- update(d20.ml,.~.-day:treatment:species)
drop1(d22, test="Chisq")
d23 <- update(d22,.~.-treatment:species)
drop1(d23, test="Chisq")
d24 <- update(d23,.~.-day:treatment)
drop1(d24, test="Chisq") #day:species (0.006)
d25 <- update(d24,.~.-treatment)
drop1(d25, test="Chisq")

plot(allEffects(d25))

ggplot(switch_pc,aes(x=day,y=PC3.dor,colour=species,linetype=species))+
  geom_hline(yintercept=0,colour="gray88",size=1.5)+
  stat_smooth(se=F,size=0.9,show.legend = T,method=glm,fullrange = T)+
  scale_colour_manual(values = c("green","red","blue"))+
  scale_y_continuous(name="Dorsal PC3")+
  scale_x_continuous(name="Day")

drop1(d25, test="Chisq")
d26 <- update(d25,.~.-day:species)
drop1(d26, test="Chisq") 
d27 <- update(d26,.~.-species)
drop1(d27, test="Chisq")
d28 <- update(d27,.~.-day)
drop1(d28, test="Chisq")


#convert back to REML prior to final determination
d28 <- update(d28,method="REML")
d28.1 <- update(d28,.~.+treatment)
anova(d28.1, test="Chisq") #treatment=0.94

d28.2 <- update(d28,.~.+day*species)
anova(d28.2, test="Chisq") #day:species = 0.0003
summary(d28.2)

d27a <- update(d27,method="REML")
summary(d27a)

####PC4####
d30 <- lme(PC4.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
d30a <- lme(PC4.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(d30,d30a) #without tank is better

d30b <- lme(PC4.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(d30a,d30b) #with position is better

d30c <- lme(PC4.dor~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|position),control=lmeControl(opt = "optim"))
AIC(d30a,d30c) #without family is better

plot(ACF(d30c),alpha=0.05)

d30.1<-update(d30c,correlation=corAR1())
plot(ACF(d30.1),alpha=0.05)

anova(d30c,d30.1) #d30.1 better

d30.2<-update(d30c,correlation=corARMA(q=2))
d30.3<-update(d30c,correlation=corARMA(q=3))
d30.4<-update(d30c,correlation=corARMA(q=5))
anova(d30.1,d30.2) 
anova(d30.1,d30.3)
anova(d30.1,d30.4) #at lag 5 is the best fit

plot(d30.4)
qqnorm(d30.4,~resid(.)|tag)

d30.ml <-update(d30.4,method="ML")

drop1(d30.ml,test="Chisq") 
d32 <- update(d30.ml,.~.-day:treatment:species)
drop1(d32, test="Chisq")
d33 <- update(d32,.~.-day:treatment)
drop1(d33, test="Chisq")
d34 <- update(d33,.~.-day:species)
drop1(d34, test="Chisq") #day sig, treatment:species sig

plot(allEffects(d34))

ggplot(switch_pc,aes(x=treatment,y=PC4.dor,colour=species))+geom_hline(yintercept=0,colour="gray61",size=0.5)+
  stat_smooth(data=switch_pc,aes(treatment,PC4.dor,colour=species,group=species),se=FALSE,size=0.8,
  show.legend = F)+
  coord_cartesian(ylim=c(-2, 2))+
  stat_summary(fun.y = mean, geom = "point",size = 4) +
  stat_summary(fun.data = mean_cl_normal, geom = "errorbar",width = 0.15,size=1)+
  scale_colour_manual(values = c("forestgreen","red2","mediumblue"))+
  scale_y_continuous(name="Dorsal PC4")+
  scale_x_discrete(name="Treatment")

drop1(d34, test="Chisq")
d35 <- update(d34,.~.-treatment:species)
drop1(d35, test="Chisq")
d36 <- update(d35,.~.-species)
drop1(d36, test="Chisq")
d37 <- update(d36,.~.-treatment)
drop1(d37, test="Chisq")
d38 <- update(d37,.~.-day)

#convert back to REML prior to final determination
d38 <- update(d38,method="REML")

d38.1 <- update(d38,.~.+day)
anova(d38.1,test="Chisq") #day<0.0001
summary(d38.1)

d34a <- update(d34,method="REML")
anova(d34a,test="Chisq") #treatment:species = 0.065
anova(d34,test="Chisq") #with ML, interaction is much more sig. 

d38.2 <- update(d38,.~.+treatment*species)
anova(d38.2,test="Chisq")  #treatment:species = 0.078 (with day excluded)


#posthoc testing using multcomp
switch_pc$inter <- interaction (switch_pc$treatment,switch_pc$species)
d38.3 <- update(d38,.~.+inter)
library(multcomp)
posthoc<-glht(d38.3, linfct=mcp(inter="Tukey"))
summary(posthoc)

####Now with Cadual colour####
####PC1####
t1 <- lme(PC1.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
t1a <- lme(PC1.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(t1,t1a) #without tank is better

t1b <- lme(PC1.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(t1a,t1b) #with position is better

t1c <- lme(PC1.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|position),control=lmeControl(opt = "optim"))
AIC(t1a,t1c) #without family is better

plot(ACF(t1c),alpha=0.05)

t1.1<-update(t1c,correlation=corAR1())
plot(ACF(t1.1),alpha=0.05)

anova(t1c,t1.1) #t1.1 is better

t1.2<-update(t1c,correlation=corARMA(q=2))
t1.3<-update(t1c,correlation=corARMA(q=3))
t1.4<-update(t1c,correlation=corARMA(q=4))
anova(t1.1,t1.2) #t1.1 is better
anova(t1.1,t1.3) #t1.3 is better
anova(t1.3,t1.4) #t1.3 is better

plot(t1.3)
qqnorm(t1.3,~resid(.)|tag)

t1.ml <-update(t1.3,method="ML")

drop1(t1.ml,test="Chisq")
t2 <- update(t1.ml,.~.-day:treatment:species)
drop1(t2, test="Chisq")
t3 <- update(t2,.~.-treatment:species)
drop1(t3, test="Chisq")
t4 <- update(t3,.~.-day:treatment)
drop1(t4, test="Chisq") 
t5 <- update(t4,.~.-day:species)
drop1(t5, test="Chisq") 
t6 <- update(t5,.~.-treatment)
drop1(t6, test="Chisq") 
t7 <- update(t6,.~.-species)
drop1(t7, test="Chisq") #day highly sig
t8 <- update(t7,.~.-day)
drop1(t8, test="Chisq")

#convert back to REML prior to final determination
t7a <- update(t7,method="REML")
anova(t7a,test="Chisq") #day<0.0001
summary(t7a)

t8 <- update(t8,method="REML")
t8.1 <- update(t8,.~.+treatment)
anova(t8.1,test="Chisq") #treatment = 0.94

t8.2 <- update(t8,.~.+species)
anova(t8.2,test="Chisq") #species=0.87


####PC2####
t10 <- lme(PC2.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
t10a <- lme(PC2.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(t10,t10a) #without tank is better

t10b <- lme(PC2.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(t10a,t10b) #with position is better

t10c <- lme(PC2.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|position),control=lmeControl(opt = "optim"))
AIC(t10a,t10c) #without family is better

plot(ACF(t10c),alpha=0.05)

t10.1<-update(t10c,correlation=corAR1())
plot(ACF(t10.1),alpha=0.05)

anova(t10c,t10.1) #t10c is better

t10.2<-update(t10c,correlation=corARMA(q=2))
t10.3<-update(t10c,correlation=corARMA(q=3))
t10.4<-update(t10c,correlation=corARMA(q=4))
anova(t10c,t10.2) 
anova(t10c,t10.3) 
anova(t10c,t10.4) #t10c best

plot(t10c)
qqnorm(t10c,~resid(.)|tag)

t10.ml <-update(t10c,method="ML")

drop1(t10.ml,test="Chisq")
t12 <- update(t10.ml,.~.-day:treatment:species)
drop1(t12, test="Chisq")
t13 <- update(t12,.~.-day:species)
drop1(t13, test="Chisq")
t14 <- update(t13,.~.-day:treatment)
drop1(t14, test="Chisq") 
t15 <- update(t14,.~.-treatment:species)
drop1(t15, test="Chisq") 
t16 <- update(t15,.~.-day)
drop1(t16, test="Chisq")
t17 <- update(t16,.~.-species)
drop1(t17, test="Chisq")
t18 <- update(t17,.~.-treatment)

#convert back to REML prior to final determination
t17a <- update(t17,method="REML")
anova(t17a,test="Chisq") #treatment=0.26

t18 <- update(t18,method="REML")
t18.1 <- update(t18,.~.+day)
anova(t18.1,test="Chisq") #day = 0.63
summary(t18.1)

t18.2 <- update(t18,.~.+species)
anova(t18.2,test="Chisq") #species = 0.28


####PC3####
t20 <- lme(PC3.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
t20a <- lme(PC3.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(t20,t20a) #without tank is better

t20b <- lme(PC3.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(t20a,t20b) #with position is better

t20c <- lme(PC3.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|position),control=lmeControl(opt = "optim"))
AIC(t20a,t20c) #without family is better

plot(ACF(t20c),alpha=0.05)

t20.1<-update(t20c,correlation=corAR1())
plot(ACF(t20.1),alpha=0.05)

anova(t20c,t20.1) #t20c better

t20.2<-update(t20c,correlation=corARMA(q=2))
t20.3<-update(t20c,correlation=corARMA(q=3))
t20.4<-update(t20c,correlation=corARMA(q=4))
anova(t20c,t20.2) 
anova(t20c,t20.3)
anova(t20c,t20.4) #t20.4 best

plot(t20.4)
qqnorm(t20.4,~resid(.)|tag)

t20.ml <-update(t20.4,method="ML")

drop1(t20.ml,test="Chisq") 
t22 <- update(t20.ml,.~.-day:treatment:species)
drop1(t22, test="Chisq")
t23 <- update(t22,.~.-treatment:species)
drop1(t23, test="Chisq")
t24 <- update(t23,.~.-day:species)
drop1(t24, test="Chisq") 
t25 <- update(t24,.~.-day:treatment)
drop1(t25, test="Chisq")
t26 <- update(t25,.~.-treatment)
drop1(t26, test="Chisq") #speces & day sig

plot(allEffects(t26))

t27 <- update(t26,.~.-species)
drop1(t27, test="Chisq")
t28 <- update(t27,.~.-day)
drop1(t28, test="Chisq")

#convert back to REML prior to final determination
t27a <- update(t27,method="REML")
anova(t27a,test="Chisq") #day=0.019
summary(t27a)

t28 <- update(t28,method="REML")
t28.1 <- update(t28,.~.+treatment)
anova(t28.1, test="Chisq") #treatment=0.85

t28.2 <- update(t28,.~.+species)
anova(t28.2, test="Chisq") #species=0.047


####PC4####
t30 <- lme(PC4.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
t30a <- lme(PC4.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(t30,t30a) #without tank is better

t30b <- lme(PC4.tail~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(t30a,t30b) #without position is better

t30c <- lme(PC4.tail~day*treatment*species, data=switch_pc, random=list(~day|tag),control=lmeControl(opt = "optim"))
AIC(t30b,t30c) #without family is better

plot(ACF(t30c),alpha=0.05)

t30.1<-update(t30c,correlation=corAR1())
plot(ACF(t30.1),alpha=0.05)

anova(t30c,t30.1) #t30c slightly better

t30.2<-update(t30c,correlation=corARMA(q=2))
t30.3<-update(t30c,correlation=corARMA(q=3))
t30.4<-update(t30c,correlation=corARMA(q=4))
anova(t30c,t30.2) 
anova(t30c,t30.3)
anova(t30c,t30.4) #t30c still best

plot(t30c)
qqnorm(t30c,~resid(.)|tag)

t30.ml <-update(t30c,method="ML")

drop1(t30.ml,test="Chisq") 
t32 <- update(t30.ml,.~.-day:treatment:species)
drop1(t32, test="Chisq")
t33 <- update(t32,.~.-day:treatment)
drop1(t33, test="Chisq")
t34 <- update(t33,.~.-treatment:species)
drop1(t34, test="Chisq") 
t35 <- update(t34,.~.-day:species)
drop1(t35, test="Chisq") 
t36 <- update(t35,.~.-treatment)
drop1(t36, test="Chisq") #species trending
t37 <- update(t36,.~.-species)
drop1(t37, test="Chisq")
t38 <- update(t37,.~.-day)
drop1(t38, test="Chisq")

#convert back to REML prior to final determination
t37a <- update(t37,method="REML")
anova(t37a,test="Chisq") #day<0.0001
summary(t37a)

t38 <- update(t38,method="REML")
t38.1 <- update(t38,.~.+treatment)
anova(t38.1,test="Chisq") #treatment = 0.53

t38.2 <- update(t38,.~.+species)
anova(t38.2,test="Chisq") #species = 0.074



####Now with Anal fin colour####
####PC1####
a1 <- lme(PC1.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
a1a <- lme(PC1.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(a1,a1a) #without tank is better

a1b <- lme(PC1.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(a1a,a1b) #without position is better

a1c <- lme(PC1.anal~day*treatment*species, data=switch_pc, random=list(~day|tag),control=lmeControl(opt = "optim"))
AIC(a1b,a1c) #without family is better

plot(ACF(a1c),alpha=0.05)

a1.1<-update(a1c,correlation=corAR1())
plot(ACF(a1.1),alpha=0.05)

anova(a1c,a1.1) #a1.1 is better

a1.2<-update(a1c,correlation=corARMA(q=2))
a1.3<-update(a1c,correlation=corARMA(q=3))
a1.4<-update(a1c,correlation=corARMA(q=4))
anova(a1.1,a1.2) #a1.1 is better
anova(a1.1,a1.3) #a1.1 is better
anova(a1.3,a1.4) #a1.1 is better

plot(a1.1)
qqnorm(a1.1,~resid(.)|tag)

a1.ml <-update(a1.1,method="ML")

drop1(a1.ml,test="Chisq")
a2 <- update(a1.ml,.~.-day:treatment:species)
drop1(a2, test="Chisq")
a3 <- update(a2,.~.-day:treatment)
drop1(a3, test="Chisq")
a4 <- update(a3,.~.-day:species)
drop1(a4, test="Chisq") 
a5 <- update(a4,.~.-treatment:species)
drop1(a5, test="Chisq") 
a6 <- update(a5,.~.-species)
drop1(a6, test="Chisq") 
a7 <- update(a6,.~.-treatment)
drop1(a7, test="Chisq") 
a8 <- update(a7,.~.-day)
drop1(a8, test="Chisq")


#convert back to REML prior to final determination
a7a <- update(a7,method="REML")
anova(a7,test="Chisq") #day=0.15
summary(a7)

a8 <- update(a8,method="REML")
a8.1 <- update(a8,.~.+treatment)
anova(a8.1,test="Chisq") #treatment = 0.39

a8.2 <- update(a8,.~.+species)
anova(a8.2,test="Chisq") #species=0.48


####PC2####
a10 <- lme(PC2.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
a10a <- lme(PC2.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(a10,a10a) #with tank is better

a10b <- lme(PC2.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|tank),control=lmeControl(opt = "optim"))
AIC(a10a,a10b) #without position is better

a10c <- lme(PC2.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|tank),control=lmeControl(opt = "optim"))
AIC(a10b,a10c) #without family is better

plot(ACF(a10c),alpha=0.05)

a10.1<-update(a10c,correlation=corAR1())
plot(ACF(a10.1),alpha=0.05)

anova(a10c,a10.1) #a10c is better

a10.2<-update(a10c,correlation=corARMA(q=2))
a10.3<-update(a10c,correlation=corARMA(q=3))
a10.4<-update(a10c,correlation=corARMA(q=4))
anova(a10c,a10.2) 
anova(a10c,a10.3) 
anova(a10c,a10.4) #a10c best

plot(a10c)
qqnorm(a10c,~resid(.)|tag)

a10.ml <-update(a10c,method="ML")

drop1(a10.ml,test="Chisq")
a12 <- update(a10.ml,.~.-day:treatment:species)
drop1(a12, test="Chisq")
a13 <- update(a12,.~.-day:treatment)
drop1(a13, test="Chisq")
a14 <- update(a13,.~.-day:species)
drop1(a14, test="Chisq") 
a15 <- update(a14,.~.-treatment:species)
drop1(a15, test="Chisq") 
a16 <- update(a15,.~.-treatment)
drop1(a16, test="Chisq")
a17 <- update(a16,.~.-species)
drop1(a17, test="Chisq")
a18 <- update(a17,.~.-day)

#convert back to REML prior to final determination
a17a <- update(a17,method="REML")
anova(a17a,test="Chisq") #day=0.0091
summary(a17a)

a18 <- update(a18,method="REML")
a18.1 <- update(a18,.~.+treatment)
anova(a18.1,test="Chisq") #treatment = 0.68

a18.2 <- update(a18,.~.+species)
anova(a18.2,test="Chisq") #species = 0.39


####PC3####
a20 <- lme(PC3.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
a20a <- lme(PC3.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(a20,a20a) #without tank is better

a20b <- lme(PC3.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(a20a,a20b) #without position is better

a20c <- lme(PC3.anal~day*treatment*species, data=switch_pc, random=list(~day|tag),control=lmeControl(opt = "optim"))
AIC(a20b,a20c) #without family is better

plot(ACF(a20c),alpha=0.05)

a20.1<-update(a20c,correlation=corAR1())
plot(ACF(a20.1),alpha=0.05)

anova(a20c,a20.1) #a20.1 better

a20.2<-update(a20c,correlation=corARMA(q=2))
a20.3<-update(a20c,correlation=corARMA(q=3))
a20.4<-update(a20c,correlation=corARMA(q=4))
anova(a20.1,a20.2) 
anova(a20.1,a20.3)
anova(a20.1,a20.4) #a20.1 best

plot(a20.1)
qqnorm(a20.1,~resid(.)|tag)

a20.ml <-update(a20.1,method="ML")

drop1(a20.ml,test="Chisq") 
a22 <- update(a20.ml,.~.-day:treatment:species)
drop1(a22, test="Chisq")
a23 <- update(a22,.~.-day:species)
drop1(a23, test="Chisq")
a24 <- update(a23,.~.-day:treatment)
drop1(a24, test="Chisq") 
a25 <- update(a24,.~.-treatment:species)
drop1(a25, test="Chisq")
a26 <- update(a25,.~.-species)
drop1(a26, test="Chisq") 
a27 <- update(a26,.~.-treatment)
drop1(a27, test="Chisq") #day sig
a28 <- update(a27,.~.-day)
drop1(a28, test="Chisq")

#convert back to REML prior to final determination
a27a <- update(a27,method="REML")
anova(a27a,test="Chisq") #day=0.039
summary(a27a)

a28 <- update(a28,method="REML")
a28.1 <- update(a28,.~.+treatment)
anova(a28.1, test="Chisq") #treatment=0.48

a28.2 <- update(a28,.~.+species)
anova(a28.2, test="Chisq") #species=0.62


####PC4####
a30 <- lme(PC4.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
a30a <- lme(PC4.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam, ~1|position),control=lmeControl(opt = "optim"))
AIC(a30,a30a) #without tank is better

a30b <- lme(PC4.anal~day*treatment*species, data=switch_pc, random=list(~day|tag, ~1|fam),control=lmeControl(opt = "optim"))
AIC(a30a,a30b) #with position is better

a30c <- lme(PC4.anal~day*treatment*species, data=switch_pc, random=list(~day|tag,~1|position),control=lmeControl(opt = "optim"))
AIC(a30a,a30c) #without family is better

plot(ACF(a30c),alpha=0.05)

a30.1<-update(a30c,correlation=corAR1())
plot(ACF(a30.1),alpha=0.05)

anova(a30c,a30.1) #a30c slightly better

a30.2<-update(a30c,correlation=corARMA(q=2))
a30.3<-update(a30c,correlation=corARMA(q=3))
a30.4<-update(a30c,correlation=corARMA(q=4))
anova(a30c,a30.2) 
anova(a30c,a30.3)
anova(a30c,a30.4) #a30c still best

plot(a30c)
qqnorm(a30c,~resid(.)|tag)

a30.ml <-update(a30c,method="ML")

drop1(a30.ml,test="Chisq") #trending 3way interaction
a32 <- update(a30.ml,.~.-day:treatment:species)
drop1(a32, test="Chisq")
a33 <- update(a32,.~.-treatment:species)
drop1(a33, test="Chisq")
a34 <- update(a33,.~.-day:treatment)
drop1(a34, test="Chisq") 
a35 <- update(a34,.~.-day:species)
drop1(a35, test="Chisq") 
a36 <- update(a35,.~.-species)
drop1(a36, test="Chisq") 
a37 <- update(a36,.~.-treatment)
drop1(a37, test="Chisq")
a38 <- update(a37,.~.-day)
drop1(a38, test="Chisq")

#convert back to REML prior to final determination
a37a <- update(a37,method="REML")
anova(a37a,test="Chisq") #day<0.0001
plot(allEffects(a37a))
summary(a37a)

a38 <- update(a38,method="REML")
a38.1 <- update(a38,.~.+treatment)
anova(a38.1,test="Chisq") #treatment = 0.26

a38.2 <- update(a38,.~.+species)
anova(a38.2,test="Chisq") #species = 0.94


#####Does brightness change with switched fish?####

str(switch_pc2)

switch_pc2$fam <- as.factor(switch_pc2$fam)
switch_pc2$momID <- as.factor(switch_pc2$momID)
switch_pc2$dadID <- as.factor(switch_pc2$dadID)
switch_pc2$tag <- as.factor(switch_pc2$tag)
switch_pc2$tank <- as.factor(switch_pc2$tank)
switch_pc2$position <- as.factor(switch_pc2$position)
switch_pc2$species <- as.factor(switch_pc2$species)
switch_pc2$treatment <- as.factor(switch_pc2$treatment)

hist(switch_pc2$bright2) #normal, ok for lme


br1 <- lme(bright2~day*treatment*species, data=switch_pc2, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position, ~1|tank),control=lmeControl(opt = "optim"))
br1a <- lme(bright2~day*treatment*species, data=switch_pc2, random=list(~day|tag, ~1|momID, ~1|dadID, ~1|position),control=lmeControl(opt = "optim"))
AIC(br1,br1a) #without tank is better

br1b <- lme(bright2~day*treatment*species, data=switch_pc2, random=list(~day|tag, ~1|momID, ~1|dadID),control=lmeControl(opt = "optim"))
AIC(br1a,br1b) #without position is better

br1c <- lme(bright2~day*treatment*species, data=switch_pc2, random=list(~day|tag,~1|momID),control=lmeControl(opt = "optim"))
AIC(br1b,br1c) #without dadID is better

br1d <- lme(bright2~day*treatment*species, data=switch_pc2, random=list(~day|tag),control=lmeControl(opt = "optim"))
AIC(br1c,br1d) #without momID is better

plot(ACF(br1d),alpha=0.05)

br1.1<-update(br1d,correlation=corAR1())
plot(ACF(br1.1),alpha=0.05)

anova(br1d,br1.1) #br1d is better

br1.2<-update(br1d,correlation=corARMA(q=2))
br1.3<-update(br1d,correlation=corARMA(q=3))
br1.4<-update(br1d,correlation=corARMA(q=4))

anova(br1d,br1.3) #br1d is better

plot(br1d)
qqnorm(br1d,~resid(.)|tag)

br1.ml <-update(br1d,method="ML")

drop1(br1.ml,test="Chisq")
br2 <- update(br1.ml,.~.-day:treatment:species)
drop1(br2,test="Chisq")
br3 <- update(br2,.~.-day:treatment)
drop1(br3,test="Chisq")
br4 <- update(br3,.~.-day:species)
drop1(br4,test="Chisq")
br5 <- update(br4,.~.-treatment:species)
drop1(br5,test="Chisq")
br6 <- update(br5,.~.-treatment)
drop1(br6,test="Chisq")
br7 <- update(br6,.~.-species)
drop1(br7,test="Chisq")
br8 <- update(br7,.~.-day)

#convert back to REML prior to final determination
br8 <- update(br8,method="REML")

anova(br7,test="Chisq") #day<0.0001
plot(allEffects(br7))
#fish are less bright over time -> less bright as they age

br8.1 <- update(br8,.~.+treatment)
anova(br8.1,test="Chisq") #treatment = 0.41

br8.2 <- update(br8,.~.+species)
anova(br8.2,test="Chisq") #species = 0.30



